@@ -56,7 +56,7 @@
 #define PROGNAME                "swverify"
 #define SW_UTILNAME             PROGNAME
 #define SWPROG_VERSION          SWVERIFY_VERSION
-#define WOPT_LAST		219   /* Highest option number */
+#define WOPT_LAST		246   /* Highest option number */
 
 static char progName[] = PROGNAME;
 static char * CHARTRUE = "True";
@@ -685,14 +685,44 @@ main(int argc, char **argv)
 		{"sig-level", 1, 0, 209},
 		{"check-mtime", 1, 0, 210},
 		{"check-volatile", 1, 0, 211},
+		{"check_volatile", 1, 0, 211},
 		{"check-contents", 1, 0, 212},
+		{"check_contents", 1, 0, 212},
 		{"check-permissions", 1, 0, 213},
+		{"check_permissions", 1, 0, 213},
 		{"check-scripts", 1, 0, 214},
+		{"check_scripts", 1, 0, 214},
 		{"show-info", 0, 0, 215},
 		{"catalog-info-name", 1, 0, 216},
 		{"system-info-name", 1, 0, 217},
 		{"dereference-symlinks", 0, 0, 218},
 		{"ignore-slack-install", 0, 0, 219},
+		{"swbis_no_remote_kill", 	1, 0, 220},
+		{"swbis-no-remote-kill", 	1, 0, 220},
+		{"swbis_local_pax_write_command", 1, 0, 222},
+		{"swbis-local-pax-write-command", 1, 0, 222},
+		{"swbis_remote_pax_write_command", 1, 0, 223},
+		{"swbis-remote-pax-write-command", 1, 0, 223},
+		{"swbis_local_pax_read_command", 1, 0, 224},
+		{"swbis-local-pax-read-command", 1, 0, 224},
+		{"swbis_remote_pax_read_command", 1, 0, 225},
+		{"swbis-remote-pax-read-command", 1, 0, 225},
+		{"swbis_local_pax_remove_command", 1, 0, 226},
+		{"swbis-local-pax-remove-command", 1, 0, 226},
+		{"swbis_remote_pax_remove_command", 1, 0, 227},
+		{"swbis-remote-pax-remove-command", 1, 0, 227},
+		{"swbis_enforce_all_signatures", 1, 0, 228},
+		{"swbis-enforce-all-signatures", 1, 0, 228},
+		{"swbis_sig_level", 1, 0, 229},
+		{"swbis-sig-level", 1, 0, 229},
+		{"swbis_no_getconf", 		1, 0, 230},
+		{"swbis-no-getconf", 		1, 0, 230},
+		{"swbis_shell_command", 	1, 0, 231},
+		{"swbis-shell-command", 	1, 0, 231},
+		{"swbis_forward_agent", 	1, 0, 236},
+		{"swbis-forward-agent", 	1, 0, 236},
+		{"swbis_check_mtime", 		1, 0, 246},
+		{"swbis-check-mtime", 		1, 0, 246},
 		{0, 0, 0, 0}
              };
 
@@ -700,31 +730,33 @@ main(int argc, char **argv)
              {
 		{"enforce_scripts", 		1, 0, 216},
 		{"installed_software_catalog",	1, 0, 217},
-		{"swbis_no_getconf", 		1, 0, 218},
-		{"swbis_shell_command", 	1, 0, 219},
-		{"swbis_no_remote_kill", 	1, 0, 220},
-		{"swbis_local_pax_write_command", 1, 0, 222},
-		{"swbis_remote_pax_write_command", 1, 0, 223},
-		{"swbis_local_pax_read_command", 1, 0, 224},
-		{"swbis_remote_pax_read_command", 1, 0, 225},
-		{"swbis_local_pax_remove_command", 1, 0, 226},
-		{"swbis_remote_pax_remove_command", 1, 0, 227},
-		{"swbis_enforce_all_signatures", 	1, 0, 228},
-		{"swbis_sig_level", 1, 0, 229},
 		{"autoselect_dependencies", 	1, 0, 231},
 		{"distribution_target_directory", 1, 0, 232},
 		{"enforce_dependencies", 	1, 0, 233},
 		{"logfile", 			1, 0, 235},
-		{"swbis_forward_agent", 	1, 0, 236},
 		{"verbose", 			1, 0, 240},
-		{"check_contents", 		1, 0, 241},
-		{"check_permissions", 		1, 0, 242},
-		{"check_requisites", 		1, 0, 243},
-		{"check_scripts", 		1, 0, 244},
-		{"check_volatile", 		1, 0, 245},
-		{"swbis_check_mtime", 		1, 0, 246},
+		/* {"check_requisites", 	1, 0, 243}, */
                {0, 0, 0, 0}
              };
+	
+	struct option std_long_options[] =
+             {
+		{"distribution", 0, 0, 'd'},
+		{"selections-file", 1, 0, 'f'},
+		{"correct", 0, 0, 'F'},
+		{"preview", 0, 0, 'p'},
+		{"installed-software", 0, 0, 'r'},
+		{"target-file", 1, 0, 't'},
+		{"extended-option", 1, 0, 'x'},
+		{"defaults-file", 1, 0, 'X'},
+		{"verbose", 0, 0, 'V'},
+		{"extension-option", 1, 0, 'W'},
+		{"help", 0, 0, '\012'},
+		{0, 0, 0, 0}
+             };
+
+
+	/* ---------------------------------------------------
 
 	struct option impl_extensions_long_options[] =
              {
@@ -772,23 +804,9 @@ main(int argc, char **argv)
 		{"check-scripts", 1, 0, 214},
 		{0, 0, 0, 0}
              };
+
+	--------------------------------------------------- */
 	
-	struct option std_long_options[] =
-             {
-		{"distribution", 0, 0, 'd'},
-		{"selections-file", 1, 0, 'f'},
-		{"correct", 0, 0, 'F'},
-		{"preview", 0, 0, 'p'},
-		{"installed-software", 0, 0, 'r'},
-		{"target-file", 1, 0, 't'},
-		{"extended-option", 1, 0, 'x'},
-		{"defaults-file", 1, 0, 'X'},
-		{"verbose", 0, 0, 'V'},
-		{"extension-option", 1, 0, 'W'},
-		{"help", 0, 0, '\012'},
-		{0, 0, 0, 0}
-             };
-       
 	struct ugetopt_option_desc main_help_desc[] =
              {
 	{"", "", "causes swverify to operate on a distribution"},
@@ -1174,43 +1192,6 @@ gotoStandardOptions:
 			set_opta(opta, SW_E_logfile, eopt_logfile);
 			SWLIB_ALLOC_ASSERT(eopt_logfile != NULL);
 			break;
-		case 218:
-		case 219:
-		case 220:
-		case 222:
-		case 223:
-		case 224:
-		case 225:
-		case 226:
-		case 227:
-		case 228:
-		case 229:
-		case 236:
-		case 241:
-		case 242:
-		case 243:
-		case 244:
-		case 245:
-		case 246:
-			optionname = getLongOptionNameFromValue(posix_extended_long_options , c);
-			SWLIB_ASSERT(optionname != NULL);
-			optionEnum = getEnumFromName(optionname, opta);
-			SWLIB_ASSERT(optionEnum > 0);
-			if (c == 229) {
-				/* Sanity check on sig_level */
-				int xres;
-				swlib_atoi(optarg, &xres);
-				if (xres != 0) {
-					sw_e_msg(G, "bad value detected for extended option: %s\n", optionname);
-					LCEXIT(1);
-				}
-			}
-			set_opta(opta, optionEnum, optarg);
-			if (swextopt_get_status()) {
-				sw_e_msg(G, "bad value detected for extended option: %s\n", optionname);
-				LCEXIT(1);
-			}
-			break;
 		default:
 			sw_e_msg(G, "error processing extended option\n");
 			sw_e_msg(G, "Try `swverify --help' for more information.\n");
@@ -1227,7 +1208,7 @@ gotoStandardOptions:
 		c = ugetopt_long(w_argc, 
 				cplob_get_list(w_arglist), 
 				"", 
-				impl_extensions_long_options, 
+				main_long_options, 
 				&w_option_index);
 		if (c == -1) break;
 	
@@ -1435,6 +1416,40 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 		case 219:
 			G->g_ignore_slack_installM = 1;
 			break;
+		case 220:
+		case 222:
+		case 223:
+		case 224:
+		case 225:
+		case 226:
+		case 227:
+		case 228:
+		case 229:
+		case 230:
+		case 231:
+		case 236:
+		case 246:
+			optionname = getLongOptionNameFromValue(main_long_options , c);
+			SWLIB_ASSERT(optionname != NULL);
+			optionEnum = getEnumFromName(optionname, opta);
+			SWLIB_ASSERT(optionEnum > 0);
+			if (c == 229) {
+				/* Sanity check on sig_level */
+				int xres;
+				swlib_atoi(optarg, &xres);
+				if (xres != 0) {
+					sw_e_msg(G, "bad value detected for extended option: %s\n", optionname);
+					LCEXIT(1);
+				}
+			}
+			set_opta(opta, optionEnum, optarg);
+			if (swextopt_get_status()) {
+				sw_e_msg(G, "bad value detected for extended option: %s\n", optionname);
+				LCEXIT(1);
+			}
+			break;
+
+
 		default:
 			sw_e_msg(G, "error processing implementation extension option : %s\n",
 				cplob_get_list(w_arglist)[w_option_index]);
@@ -1765,7 +1780,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 		target_path = swc_validate_targetpath(
 					target_nhops, 
 					tmpcharp, 
-					eopt_distribution_target_directory, cwd);
+					eopt_distribution_target_directory, cwd, "target");
 
 		SWLIB_ASSERT(target_path != NULL);
 		E_DEBUG2("target_path is [%s]", target_path);
