@@ -892,10 +892,10 @@ swc_form_command_args(GB * G,
 }
 
 char *
-swc_validate_targetpath(int nhops, char * targetpath, char * default_target, char * cwd)
+swc_validate_targetpath(int nhops, char * targetpath, char * default_target, char * cwd, char * context)
 {
 	if (nhops < 0 ) {
-		fprintf(stderr, "%s: target error\n", swlib_utilname_get());
+		fprintf(stderr, "%s: %s error\n", swlib_utilname_get(), context);
 		return NULL;
 	}
 
@@ -904,6 +904,7 @@ swc_validate_targetpath(int nhops, char * targetpath, char * default_target, cha
 		targetpath = default_target;
 	}
 
+	E_DEBUG("");
 	if (
 		nhops == 0 &&
 		*targetpath == ':'
@@ -928,6 +929,7 @@ swc_validate_targetpath(int nhops, char * targetpath, char * default_target, cha
 		}
 	}
 
+	E_DEBUG("");
 	if (nhops == 0 && strncmp(targetpath, "\\:", 2) == 0) {
 		/*
 		* handle escaped colon ':'
@@ -935,6 +937,7 @@ swc_validate_targetpath(int nhops, char * targetpath, char * default_target, cha
 		targetpath++;
 	}
 
+	E_DEBUG("");
 	if (nhops > 0 && strcmp(default_target, "-") == 0) {
 		/*
 		* This combination, stdout on a remote host makes
@@ -946,6 +949,7 @@ swc_validate_targetpath(int nhops, char * targetpath, char * default_target, cha
 		default_target = ".";
 	}
 
+	E_DEBUG("");
 	if (targetpath == (char*)NULL || strlen(targetpath) == 0) {
 		targetpath = default_target;
 		if (nhops >= 1 && (*targetpath) == '\0' ) {
@@ -956,12 +960,15 @@ swc_validate_targetpath(int nhops, char * targetpath, char * default_target, cha
 		}
 	}
 
+	E_DEBUG("");
 	if (swlib_is_sh_tainted_string(targetpath)) {
+		E_DEBUG2("string tainted with shell meta-characters: %s", targetpath);
 		swlib_doif_writef(1, -1, 0, STDERR_FILENO, 
-			"illegal target directory.\n");
+			"%s directory name is tainted with shell meta-characters\n", context);
 		return NULL;
 	}
 
+	E_DEBUG("");
 	if (strcmp(targetpath, "-")) {
 		if (strcmp(targetpath, ".") == 0) {
 			/*
@@ -979,6 +986,7 @@ swc_validate_targetpath(int nhops, char * targetpath, char * default_target, cha
 			return NULL;
 		}
 	}
+	E_DEBUG("");
 	return strdup(targetpath);
 }
 
