@@ -62,7 +62,6 @@ extern struct g_pax_read_command g_pax_read_commands[];
 
 #define SWBIS_DEFAULT_REVISION "0.0"
 
-
 static
 int
 construct_controlsh_script(GB * G, STROB * buf, SWI * swi)
@@ -285,6 +284,7 @@ sanity_compare(AHS * ahs1, AHS * ahs2, char * filename, int do_be_verbose)
 
 	if (cpiotype1 != cpiotype2) {
 		ret ++;
+		if (do_be_verbose)
 		fprintf(stderr, "%s: attribute mismatch: %s: att=type: storage=[%d] [%d]\n",
 			swlib_utilname_get(), filename,
 			(int)(cpiotype1),
@@ -294,6 +294,7 @@ sanity_compare(AHS * ahs1, AHS * ahs2, char * filename, int do_be_verbose)
        	if  ((h2->usage_maskM) & TARU_UM_MODE) {
 		if ((07777 & h1->c_mode) != (07777 & h2->c_mode)) {
 			ret ++;
+			if (do_be_verbose)
 			fprintf(stderr, "%s: attribute mismatch: %s: att=mode: storage=[%o] [%o]\n",
 				swlib_utilname_get(), filename,
 				(int)(h1->c_mode),
@@ -311,6 +312,7 @@ sanity_compare(AHS * ahs1, AHS * ahs2, char * filename, int do_be_verbose)
 			h1->c_uid != h2->c_uid
 		) {
 			ret ++;
+			if (do_be_verbose)
 			fprintf(stderr, "%s: attribute mismatch: %s: att=uid: storage=[%d] INFO=[%d]\n",
 				swlib_utilname_get(), filename,
 				(int)(h1->c_uid),
@@ -328,6 +330,7 @@ sanity_compare(AHS * ahs1, AHS * ahs2, char * filename, int do_be_verbose)
 			h1->c_gid != h2->c_gid
 		) {
 			ret ++;
+			if (do_be_verbose)
 			fprintf(stderr, "%s: attribute mismatch: %s: att=gid: storage=[%d] INFO=[%d]\n",
 				swlib_utilname_get(), filename,
 				(int)(h1->c_gid),
@@ -342,6 +345,7 @@ sanity_compare(AHS * ahs1, AHS * ahs2, char * filename, int do_be_verbose)
        	if ( ((h2->usage_maskM) & TARU_UM_MTIME) && h1->c_mtime != h2->c_mtime) {
 		/* This is now only a warning. */
 		/* ret ++; FIXME:  policy at wrong level */
+		if (do_be_verbose)
 		fprintf(stderr, "%s: Warning: attribute mismatch: %s: att=mtime: storage=[%lu] INFO=[%lu]\n",
 			swlib_utilname_get(), filename,
 			(h1->c_mtime),
@@ -361,6 +365,7 @@ sanity_compare(AHS * ahs1, AHS * ahs2, char * filename, int do_be_verbose)
 		 * Don't do a file size comparison if the type is SYMTYPE or LNKTYPE
 		 */
 		ret ++;
+		if (do_be_verbose)
 		fprintf(stderr, "%s: attribute mismatch: %s: att=size: storage=[%d] INFO=[%d]\n",
 			swlib_utilname_get(), filename,
 			(int)(h1->c_filesize),
@@ -371,6 +376,7 @@ sanity_compare(AHS * ahs1, AHS * ahs2, char * filename, int do_be_verbose)
        	if ((h1->c_dev_maj || h2->c_dev_maj) && 
 		h1->c_dev_maj != h2->c_dev_maj) {
 		ret ++;
+		if (do_be_verbose)
 		fprintf(stderr, "%s: attribute mismatch: %s: att=major: storage=[%d] INFO=[%d]\n",
 			swlib_utilname_get(), filename,
 			(int)(h1->c_dev_maj),
@@ -380,6 +386,7 @@ sanity_compare(AHS * ahs1, AHS * ahs2, char * filename, int do_be_verbose)
        	if ((h1->c_dev_min || h2->c_dev_min) &&
        		h1->c_dev_min != h2->c_dev_min) {
 		ret ++;
+		if (do_be_verbose)
 		fprintf(stderr, "%s: attribute mismatch: %s: att=minor: storage=[%d] INFO=[%d]\n",
 			swlib_utilname_get(), filename,
 			(int)(h1->c_dev_min),
@@ -575,7 +582,10 @@ get_delivery_size(SWI * swi, int * result)
 	}
 
 	size = 	size + 			/* the fileset size value */
-		(count * 2048) +	/* header and last block for every file + 1024 extra pad */
+		(count * 2048) +	/* header and last block for every file + 1024 extra pad,
+					   this should *more* than account for extended headers and
+					   special device files and directories that are not counted
+					   in the fileset size */
 		(10 * 512);		/* trailer blocks, 10 is arbitrary */
 
 	/*
@@ -916,6 +926,7 @@ construct_execution_phase_script(GB * G, SWI * swi,
 		"case $? in\n"
 		"	0)\n"
 		"	%s\n"
+		"	umask 077\n"
 		"	dd 2>/dev/null | %s\n"
 		"	sw_retval=$?\n"
 		"	dd of=/dev/null 2>/dev/null\n"
@@ -1018,6 +1029,155 @@ construct_directory_ownership_script(SWI * swi, STROB * dir_owner_buf, char * is
 	return;
 }
 
+static
+int
+send_files_with_no_storage(GB * G, SWI * swi, SWHEADER * infoheader, XFORMAT * xformat, int fileset_fd, int vofd,
+				int * pstatus, char * target_path, char * location,
+				char * directory, uintmax_t * pstatbytes)
+{
+	int ret;
+	int retval;
+	int tartype;
+	int header_ret;
+	char * att;
+	char * next_line;
+	char * keyword;
+	char * missing_name;
+	char * current_path;
+	char * l_current_path;
+	AHS * ahs;
+	char *current_type;
+	char * current_link_source;
+	STROB * relocated_current_path;
+
+	relocated_current_path = strob_open(10);
+	retval = 0;
+	ret = 0;
+	ahs = ahs_open();
+	*pstatus = 0;
+
+	swheader_store_state(infoheader, NULL);
+	swheader_reset(infoheader);
+	while((next_line=swheader_get_next_object(infoheader, (int)UCHAR_MAX, (int)UCHAR_MAX))) {
+		keyword = swheaderline_get_keyword(next_line);
+		SWLIB_ASSERT(keyword != NULL);
+		if (strcmp(keyword, SW_A_control_file) == 0) {
+			/* skip control files */
+			continue;
+		}
+		if (swheaderline_get_flag1(next_line) == 0) {
+			/* These files have no file in the storage section */
+
+			ahs_init_header(ahs);
+			ret = swheader_fileobject2filehdr(infoheader, ahs_vfile_hdr(ahs));
+			if (ret) {
+				SWI_internal_error();
+				*pstatus = 2; /* error */
+				break;
+			}	
+			tartype = ahs_get_tar_typeflag(ahs);
+
+			att = swheader_get_attribute(infoheader, SW_A_type);
+			SWLIB_ASSERT(att != NULL);
+			current_type = swheaderline_get_value(att, NULL);
+
+			att = swheader_get_attribute(infoheader, SW_A_path);
+			SWLIB_ASSERT(att != NULL);
+			current_path = swheaderline_get_value(att, NULL);
+			
+			swlib_apply_location(relocated_current_path, current_path, location, directory);
+
+			swpl_sanitize_pathname(strob_str(relocated_current_path));
+			swlib_squash_leading_dot_slash(strob_str(relocated_current_path));
+			swlib_squash_leading_slash(strob_str(relocated_current_path));
+			l_current_path = strob_str(relocated_current_path);
+
+			ahsStaticSetTarFilename(ahs_vfile_hdr(ahs), l_current_path);
+
+			if (*current_type == SW_ITYPE_f) {
+				/* REGTYPE */
+				*pstatus = 1; /* error */
+				continue;
+			} else if (
+				*current_type == SW_ITYPE_d || /* directory */
+				*current_type == SW_ITYPE_s || /* sym link */
+				*current_type == SW_ITYPE_c || /* char device */
+				*current_type == SW_ITYPE_b || /* block device */
+				0
+			) {
+				detect_and_correct_numeric_ids(ahs);
+				ahs_copy(xformat_ahs_object(xformat) /*to*/ , ahs /*from*/);
+
+				if (*current_type == SW_ITYPE_h || *current_type == SW_ITYPE_s) {
+					att = swheader_get_attribute(infoheader, SW_A_link_source);
+					SWLIB_ASSERT(att != NULL);
+					current_link_source = swheaderline_get_value(att, NULL);
+					if (!current_link_source) {
+						*pstatus = 3;
+						SWI_internal_error();
+						break;
+					}
+
+					if (strlen(current_link_source) > TARLINKNAMESIZE) {
+						fprintf(stderr, "tar link name too long\n");
+						SWI_internal_error();
+						*pstatus = 4;
+						break;
+					}
+					if (strcmp(target_path, "/") != 0) {
+						swpl_sanitize_pathname(current_link_source);
+					}
+					taru_set_new_linkname(xformat->taruM, (struct tar_header *)NULL, current_link_source);
+					ahsStaticSetTarLinkname(
+						ahs_vfile_hdr(xformat_ahs_object(xformat)),
+						 current_link_source);
+				} else {
+					taru_set_new_linkname(xformat->taruM, (struct tar_header *)NULL, "");
+					ahsStaticSetTarLinkname(ahs_vfile_hdr(xformat_ahs_object(xformat)), "");
+				}
+
+				if (pstatbytes) {
+					off_t meter_len;
+					*pstatbytes = 0;
+					meter_len = (off_t)0;
+					start_progress_meter(STDOUT_FILENO, l_current_path, meter_len, pstatbytes);
+					*swlib_pump_get_ppstatbytes() = pstatbytes;
+				}
+
+				if (fileset_fd != vofd) {
+					/*
+					 * This code path is used in preview mode.
+					 */
+					xformat_set_ofd(xformat, fileset_fd);
+					header_ret = xformat_write_header(xformat);
+					xformat_set_ofd(xformat, vofd);
+				} else {
+					/*
+					 * Normal fast path.
+					 */
+					header_ret = xformat_write_header(xformat);
+				}	
+
+				if (header_ret < 0) {
+					SWI_internal_error();
+					*pstatus = 4;
+					break;
+				}
+				retval += header_ret;
+
+
+			} else {
+				/* FIXME, need to support other types */	
+				;
+			}
+		}
+	}
+	swheader_restore_state(infoheader, NULL);
+	strob_close(relocated_current_path);
+	ahs_close(ahs);
+	return retval;
+}
+
 int
 run_analysis_script(GB * G, SWI * swi, int ofd, int event_fd, int * p_checkinstall_status)
 {
@@ -1164,6 +1324,8 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	int cmpret = 0;
 	int size_result;
 	int taru_ls_verbose_level = -1;
+	int signal_flag;
+	int * p_signal_flag;
 	char * current_path;
 	char * l_current_path;
 	char * current_type;
@@ -1173,6 +1335,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	int ifd;
 	int fileset_fd;
 	int ret;
+	int ret2;
 	int parseret;
 	int is_catalog;
 	int data_amount;
@@ -1218,7 +1381,6 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	uintmax_t filesize;
 	int eoa;
 	int header_ret;
-	int current_file_offset;
 	char * log_level_str;
 	int log_level;
 	char * md5buf;
@@ -1232,6 +1394,10 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	char * p_directory;
 	SWVERID * swverid;
 
+	signal_flag = 0;
+	p_signal_flag = &signal_flag;
+	if (g_signal_flag)
+		p_signal_flag = g_signal_flag;
 	do_check_abort = 0;
 	checkinstall_status = -1; /* unset value */
 	files_missing_from_storage = 0;
@@ -1445,7 +1611,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	 */
 
 	while ((read_header_ret = xformat_read_header(xformat)) > 0 &&
-			(!g_signal_flag || (g_signal_flag && *g_signal_flag == 0))) {
+			(*p_signal_flag == 0)) {
 		
 		E_DEBUG("HERE");
 		if (xformat_is_end_of_archive(xformat)){
@@ -1871,7 +2037,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 	taru_ls_verbose_level = -1;
 	while (
 		xformat_read_header(xformat) > 0 &&
-		(!g_signal_flag || (g_signal_flag && *g_signal_flag == 0)) &&
+		*p_signal_flag == 0 &&
 		retval == 0
 	) {
 		E_DEBUG("HERE: Storage");
@@ -1955,19 +2121,25 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			}
 
 			if (obj == (char*)NULL) {
-				/*
-				* This is a hard error, a storage file must have metadata.
-				*/
-				fprintf(stderr, "%s: File object not found for path=%s\n", swlib_utilname_get(), current_path);
-				fprintf(stderr, "%s: This may be a implementation error or an invalid package\n", swlib_utilname_get());
-				SWI_internal_error();
-				return -58;
+				if (xformat_get_tar_typeflag(xformat) == DIRTYPE) {
+					/* allow extra leading directories in the storage
+					   section since they are unavoidable when lifting
+					   the source from the directory form of a 
+					   distribution */
+					continue;
+				} else {
+					/*
+					* This is a hard error, a storage file must have metadata.
+					*/
+					fprintf(stderr, "%s: File object not found for path=%s\n", swlib_utilname_get(), current_path);
+					fprintf(stderr, "%s: This may be a implementation error or an invalid package\n", swlib_utilname_get());
+					SWI_internal_error();
+					return -58;
+				}
 			}
 
-			current_file_offset = swheader_get_current_offset(infoheader);
 			current_type = swheader_get_attribute(infoheader, "type");
 			current_type = swheaderline_get_value(current_type, NULL);
-			swheader_set_current_offset(infoheader, current_file_offset);
 
 			if (!current_type) { 
 				SWI_internal_error();
@@ -2014,23 +2186,15 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 				return -62;
 			}
 
-
-			/*
-			 * Restore the offset of the current file object
-			 */
-			swheader_set_current_offset(infoheader, current_file_offset);
-
 			/*
 			 * Find the "md5sum" attribute.
 			 */
 			filemd5 = swpl_get_attribute(infoheader, "md5sum", (int *)NULL);
-			swheader_set_current_offset(infoheader, current_file_offset);
 
 			/*
 			 * Find the "is_volatile" attribute.
 			 */
 			is_volatile = swpl_get_attribute(infoheader, "is_volatile", (int *)NULL);	
-			swheader_set_current_offset(infoheader, current_file_offset);
 
 			if (swextopt_is_value_true(is_volatile)) {
 				/*
@@ -2090,16 +2254,16 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 				cmpret++;
 			}
 
-			/*
-			 * Impose the stats from the INFO file.
-			 */				
-			ahs_copy(xformat_ahs_object(xformat), info_ahs2);
-
 			/*
 			 * handle INFO files where uid and uname are the same string
 			 */
 			detect_and_correct_numeric_ids(info_ahs2);
 
+			/*
+			 * Impose the stats from the INFO file.
+			 */				
+			ahs_copy(xformat_ahs_object(xformat), info_ahs2);
+
 			/*
 			 * Set the sanitized, relocated name.
 			 */
@@ -2113,7 +2277,6 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 			if (*current_type == SW_ITYPE_h || *current_type == SW_ITYPE_s) {
 				current_link_source = swheader_get_attribute(infoheader, SW_A_link_source);
 				current_link_source = swheaderline_get_value(current_link_source, NULL);
-				swheader_set_current_offset(infoheader, current_file_offset);
 				if (!current_link_source) { SWI_internal_error(); return -68; }
 
 				if (strlen(current_link_source) > TARLINKNAMESIZE) {
@@ -2303,7 +2466,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		storage section */
 
 	E_DEBUG("HERE");
-	if (g_signal_flag == 0 && retval == 0) {
+	if (*p_signal_flag == 0 && retval == 0) {
 		/* The routine swheaderline_set_flag1() called above
 		   tags the file objects as they are installed */
 		ret = swpl_assert_all_file_definitions_installed(swi, infoheader);
@@ -2311,8 +2474,27 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		ret = 0;
 	}
 
-	if (ret)
+	if (ret) {
+		/* some files are missing, it is acceptable that
+		   directories and non-REGTYPE files not appear in the
+		   storage section.  Send tar headers for these files based on
+		   the attributes in the INFO file and if all are non-REGTYPE then
+		   avert this error. */
+		ret2 = 1;
+		ret = send_files_with_no_storage(G, swi, infoheader, xformat, fileset_fd, vofd, &ret2, target_path,
+						p_location, p_directory, pstatbytes);
+		fileset_write_ret += ret;
+	} else {
+		ret2 = 0;
+	}
+
+	if (ret2) {
+		/*
+		 * this is an error
+		 */
+		E_DEBUG("STORAGE FILE error");
 		files_missing_from_storage = 1;
+	}
 
 	E_DEBUG("HERE");
 	if (opt_preview == 0) {
@@ -2353,7 +2535,7 @@ arfinstall_tar(GB * G, SWI * swi, int ofd,
 		ret = swlib_pad_amount(vofd, padamount);
 		E_DEBUG("HERE");
 		if (ret != padamount) {
-			if (g_signal_flag == 0) {
+			if (*p_signal_flag == 0) {
 				/* this may happen when ctl-c is given by the user */
 				SWBIS_ERROR_IMPL();
 				fprintf(stderr, "%s: swlib_pad_amount returned [%d]\n", swlib_utilname_get(), padamount);
