@@ -56,7 +56,7 @@
 #define PROGNAME                "swlist"
 #define SW_UTILNAME             PROGNAME
 #define SWPROG_VERSION          SWLIST_VERSION
-#define WOPT_LAST		213   /* Highest option number */
+#define WOPT_LAST		238   /* Highest option number */
 
 static char progName[] = PROGNAME;
 static char * CHARTRUE = "True";
@@ -752,72 +752,38 @@ main(int argc, char **argv)
 		{"exrequisite", 1, 0, 210}, 
 		{"directory-form", 0, 0, 211},
 		{"sig-level", 1, 0, 212},
-		{"system", 0, 0, 213},  /* WOPT_LAST */ 
+		{"system", 0, 0, 213},
+		{"swbis_no_getconf", 		1, 0, 218},
+		{"swbis-no_getconf", 		1, 0, 218},
+		{"swbis_shell_command", 	1, 0, 219},
+		{"swbis-shell_command", 	1, 0, 219},
+		{"swbis_no_remote_kill", 	1, 0, 220},
+		{"swbis-no-remote-kill", 	1, 0, 220},
+		{"swbis_local_pax_write_command", 1, 0, 222},
+		{"swbis-local-pax-write_command", 1, 0, 222},
+		{"swbis_remote_pax_write_command", 1, 0, 223},
+		{"swbis-remote-pax-write_command", 1, 0, 223},
+		{"swbis_local_pax_read_command", 1, 0, 224},
+		{"swbis-local-pax-read-command", 1, 0, 224},
+		{"swbis_remote_pax_read_command", 1, 0, 225},
+		{"swbis-remote-pax-read-command", 1, 0, 225},
+		{"swbis_forward_agent", 	1, 0, 236},
+		{"swbis-forward-agent", 	1, 0, 236},
+		{"swbis_sig_level", 1, 0, 237},
+		{"swbis-sig-level", 1, 0, 237},
+		{"swbis_enforce_all_signatures", 1, 0, 238},
+		{"swbis-enforce-all-signatures", 1, 0, 238},
 		{0, 0, 0, 0}
              };
 
 	struct option posix_extended_long_options[] =
              {
-		{"distribution_target_directory", 1, 0, 232},
 		{"verbose", 			1, 0, 216},
 		{"installed_software_catalog",	1, 0, 217},
-		{"swbis_no_getconf", 		1, 0, 218},
-		{"swbis_shell_command", 	1, 0, 219},
-		{"swbis_no_remote_kill", 	1, 0, 220},
 		{"one_liner",		 	1, 0, 221},
-		{"swbis_local_pax_write_command", 1, 0, 222},
-		{"swbis_remote_pax_write_command", 1, 0, 223},
-		{"swbis_local_pax_read_command", 1, 0, 224},
-		{"swbis_remote_pax_read_command", 1, 0, 225},
-		{"swbis_forward_agent", 	1, 0, 236},
-		{"swbis_sig_level", 1, 0, 237},
-		{"swbis_enforce_all_signatures", 	1, 0, 238},
+		{"distribution_target_directory", 1, 0, 232},
                {0, 0, 0, 0}
              };
-
-	struct option impl_extensions_long_options[] =
-             {
-		{"noop", 0, 0, 154},
-		{"show-options", 0, 0, 158},
-		{"show-options-files", 0, 0, 159},
-		{"testnum", 1, 0, 164},
-		{"force-locks", 0, 0, 167},
-		{"remote-shell", 1, 0, 172},
-		{"local-pax-write-command", 1, 0, 175},
-		{"remote-pax-write-command", 1, 0, 176},
-		{"pax-write-command", 1, 0, 177},
-		{"remote-pax-read-command", 1, 0, 178},
-		{"local-pax-read-command", 1, 0, 179},
-		{"pax-read-command", 1, 0, 180},
-		{"no-defaults-files", 0, 0, 181},
-		{"pax-command", 1, 0, 182},
-		{"no-remote-kill", 0, 0, 184},
-		{"no-getconf", 0, 0, 185},
-		{"use-getconf", 0, 0, 186},
-		{"shell-command", 1, 0, 188},
-		{"ssh-options", 1, 0, 195},
-		{"debug-events", 0, 0, 196},
-		{"source-script-name", 1, 0, 198},
-		{"target-script-name", 1, 0, 199},
-		{"any-format", 0, 0, 200},
-		{"swi-debug-name", 1, 0, 201},
-		{"debug-task-scripts", 0, 0, 202},
-		{"enable-ssh-agent-forwarding", 0, 0, 203},
-		{"A", 0, 0, 203},
-		{"disable-ssh-agent-forwarding", 0, 0, 204},
-		{"a", 0, 0, 204},
-		{"products", 0, 0, 205},
-		{"files", 0, 0, 206},
-		{"test1", 0, 0, 207},
-		{"deps", 0, 0, 208},
-		{"dependencies", 0, 0, 208},
-		{"prerequisites", 1, 0, 209},
-		{"exrequisites", 1, 0, 210}, 
-		{"directory-form", 0, 0, 211},
-		{"sig-level", 1, 0, 212},
-		{"system", 0, 0, 213},  /* WOPT_LAST */ 
-		{0, 0, 0, 0}
-             };
 	
 	struct option std_long_options[] =
              {
@@ -1202,27 +1168,12 @@ gotoStandardOptions:
 			eopt_installed_software_catalog = strdup(optarg);
 			set_opta(opta, SW_E_installed_software_catalog, eopt_installed_software_catalog);
 			break;
-		case 218:
-		case 219:
 		case 221:
-		case 220:
-		case 222:
-		case 223:
-		case 224:
-		case 225:
-		case 229:
-		case 236:
-		case 237:
-		case 238:
 			optionname = getLongOptionNameFromValue(posix_extended_long_options , c);
 			SWLIB_ASSERT(optionname != NULL);
 			optionEnum = getEnumFromName(optionname, opta);
 			SWLIB_ASSERT(optionEnum > 0);
 			set_opta(opta, optionEnum, optarg);
-			if (swextopt_get_status()) {
-				sw_e_msg(G, "bad value detected for extended option: %s\n", optionname);
-				LCEXIT(1);
-			}
 			break;
 		default:
 			sw_e_msg(G, "error processing extended option\n");
@@ -1236,11 +1187,11 @@ gotoStandardOptions:
 
 	/*  Now run the Implementation extension options (-W) through getopt.  */
 	while (1) {
-		int w_option_index = 0;
+		int w_option_index = 1;
 		c = ugetopt_long(w_argc, 
 				cplob_get_list(w_arglist), 
 				"", 
-				impl_extensions_long_options, 
+				main_long_options, 
 				&w_option_index);
 		if (c == -1) break;
 	
@@ -1479,12 +1430,44 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 			wopt_pgm_mode_explicitly_set = 1;
 			wopt_file_sys = 1;
 			break;
+
+		case 219:
+		case 222:
+		case 223:
+		case 224:
+		case 225:
+		case 237:
+			optionname = getLongOptionNameFromValue(main_long_options , c);
+			SWLIB_ASSERT(optionname != NULL);
+			optionEnum = getEnumFromName(optionname, opta);
+			SWLIB_ASSERT(optionEnum > 0);
+			set_opta(opta, optionEnum, optarg);
+			break;
+
+		case 238:
+		case 220:
+		case 218:
+		case 236:
+			optionname = getLongOptionNameFromValue(main_long_options , c);
+			SWLIB_ASSERT(optionname != NULL);
+			E_DEBUG2("option name is [%s]", optionname);
+			optionEnum = getEnumFromName(optionname, opta);
+			SWLIB_ASSERT(optionEnum > 0);
+			set_opta_boolean(opta, optionEnum, optarg);
+			break;
+
 		default:
 			sw_e_msg(G, "error processing implementation extension option : %s\n",
 				cplob_get_list(w_arglist)[w_option_index]);
 		 	exit(1);
 		break;
 		}
+
+		if (swextopt_get_status()) {
+			sw_e_msg(G, "bad value detected for extended option: %s\n", optionname);
+			LCEXIT(1);
+		}
+
 		if (do_extension_options_via_goto == 1) {
 			do_extension_options_via_goto = 0;
 			goto gotoStandardOptions;
@@ -1762,7 +1745,7 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 		target_path = swc_validate_targetpath(
 					target_nhops, 
 					tmpcharp, 
-					eopt_distribution_target_directory, cwd);
+					eopt_distribution_target_directory, cwd, "target");
 
 		SWLIB_ASSERT(target_path != NULL);
 		E_DEBUG2("target_path is [%s]", target_path);
@@ -2244,7 +2227,6 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 			ret = swpl_send_success(swicol, target_fdar[1], G->g_swi_event_fd,
 						SWBIS_TS_Do_nothing ": testing 123");
 
-			/* if (strar_num_elements(BL->attributesM) > 0) { */
 			if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_ATT) == 0) {
 
 				/* The -a <attribute> option was used */
@@ -2339,16 +2321,9 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 
 			} else if (swpl_test_pgm_mode(wopt_pgm_mode, SWLIST_PMODE_FILE) == 0) {
 				/* This section will list the files in installed software */	
-				/* This section Not implemented yet */
 
-				/*
-				ret = swicat_r_get_installed_catalog(G, swspecs, target_path);
-				*/
-				E_DEBUG("error");
 
-				/* BEGIN */
-
-				/* Sample abort code
+				/* Sample abort code (for reference)
 				sw_e_msg(G, "file listing for installed software not yet implemented\n");
 				swicol_set_master_alarm(swicol);
 				swicol_set_task_idstring(swicol, SWBIS_TS_Get_iscs_listing);
@@ -2363,7 +2338,6 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 				 * ===========================================================
 				 */
 
-				if (0 || 1) {
 				E_DEBUG("");
 				if (f_retval == 0) {
 					response_img = swpl_get_samepackage_query_response(G, swicol, target_path,
@@ -2524,8 +2498,9 @@ E_DEBUG2("current_arg=[%s]", current_arg);
 					f_retval++;
 				}
 
-				if (s_retval) f_retval ++;
-				}
+				if (s_retval)
+					f_retval ++;
+
 				/*
 				 * ===========================================================
 				 * ===========================================================
