@@ -201,7 +201,7 @@ ls_fileset_from_iscat(SWI * swi, int ofd, int ls_verbose)
 
         while ((next_line=swheader_get_next_object(infoheader, (int)UCHAR_MAX, (int)UCHAR_MAX))) {
 
-		E_DEBUG2("next_line=%s\n", next_line);
+		E_DEBUG2("next_line=%s", next_line);
 		if (swheaderline_get_type(next_line) != SWPARSE_MD_TYPE_OBJ) {
 			/* Sanity check */
 			SWBIS_IMPL_ERROR_DIE(1);
@@ -1066,7 +1066,7 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 		/* Bad signature or not enough good signatures
 		   Can't use the blob to make a removal file list
 		   because were assuming its tainted. */
-		E_DEBUG("");
+		E_DEBUG("sig level not satisfied");
 		rstatus = SWP_RP_STATUS_NO_INTEGRITY;
 		retval = 0;
 		do_skip_entry = 1;
@@ -1199,6 +1199,7 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 		do_skip_entry ||
 		0
 	) {
+		E_DEBUG("NOT running swpl_retrieve_files");
 		ret = swpl_send_nothing_and_wait(swicol, ofd, G->g_swi_event_fd,
                         SWBIS_TS_retrieve_files_archive,
 			SWICOL_TL_8,
@@ -1209,8 +1210,9 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			retval = -1;
 		}
 	} else {
-		E_DEBUG("");
-		archive_fd = swlib_open_memfd();
+		E_DEBUG("running swpl_retrieve_files");
+		/* archive_fd = STDOUT_FILENO; */
+		archive_fd = G->g_nullfd;
 		SWLIB_ASSERT(archive_fd > 0);
 
 		E_DEBUG("");
@@ -1247,31 +1249,26 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 	E_DEBUG("");
 
 	/* --------------------------------------------------*/
+	/* Now, read the payload which is a tar archive      */
 	/* --------------------------------------------------*/
 
-	/* Now, do the payload function */
-
 	if (wopt_file_sys) {
+		E_DEBUG("List files from file system (above)");
 		/* see swpl_retrieve_files() invocation above */
 		;
 	} else {
 		/* List file from the installed catalog */
 	
 		/* swpl_show_file_list(G, file_list); */
-		if (do_skip_entry == 0)
+		if (do_skip_entry == 0) {
+			E_DEBUG("List files from installed catalog");
 			ret = ls_fileset_from_iscat(swi, STDOUT_FILENO, ls_verbose);
+		} else {
+			;
+			E_DEBUG("skipping listing files from installed catalog");
+		}
 	}
 
-	/* --------------------------------------------------*/
-	/* --------------------------------------------------*/
-
-	/*
-	E_DEBUG2("archive_fd = %d", archive_fd);
-	uxfio_lseek(archive_fd, 0, SEEK_SET);
-	swlib_tee_to_file("/tmp/xxtar", archive_fd, NULL, -1, 0);
-	*/
-
-	if (archive_fd >= 0) uxfio_close(archive_fd);
 	archive_fd = -1;
 
 	E_DEBUG("");
@@ -1290,11 +1287,13 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			SWICOL_TL_8,
 			SW_SUCCESS);
 		if (ret != 0) {
+			E_DEBUG("swpl_send_nothing_and_wait(SWBIS_TS_Catalog_dir_remove) returned error");
 			looper_abort(G, swicol, ofd);
 			goto error_out;
 			retval = -1;
 		}
         } else {
+		E_DEBUG("Remove catalog dir");
                 /* TS_Catalog_dir_remove */
                 ret = swpl_remove_catalog_directory(swi, ofd,
 			catalog_entry_directory,
@@ -1302,6 +1301,7 @@ swlist_looper_sr_payload(GB * G, char * target_path, SWICOL * swicol,
 			0 /*alt_catalog_root*/,
 			G->g_swi_event_fd);
 		if (ret != 0) {
+			E_DEBUG("swpl_remove_catalog_directory returned error");
 			looper_abort(G, swicol, ofd);
 			goto error_out;
 			retval = -1;
