@@ -517,7 +517,7 @@ swpl_set_detected_catalog_perms(SWI * swi, ETAR * etar, int tar_type)
 	mode = swi->swi_pkgM->installed_catalog_modeM;
 	if (mode > 0) {
 		if (tar_type == REGTYPE) {
-			mode &= ~(S_IXUSR|S_IXGRP|S_IXOTH);
+			mode &= ~(S_IXUSR|S_IXGRP|S_IXOTH|S_ISVTX);
 		}
 		etar_set_mode_ul(etar, (unsigned int)(mode));
 	}
@@ -1591,7 +1591,12 @@ swpl_write_out_signature_member(SWI * swi, struct tar_header * ptar_hdr,
 	 */
 
 	etar_set_size(etar, siglen);
-	etar_set_mode_ul(etar, (unsigned int)(0640));
+	
+	/*
+	 * set the mode of the catalog top level directory
+	 *    was:  etar_set_mode_ul(etar, (unsigned int)(0640));
+	 */
+	swpl_set_detected_catalog_perms(swi, etar, REGTYPE);
 
 	strob_strcpy(tmp, SWINSTALL_INCAT_NAME);
 	swlib_unix_dircat(tmp, SWINSTALL_CATALOG_TAR);
@@ -3674,7 +3679,12 @@ swpl_make_verify_command_script_fragment(GB * G,
 	/* priint each file */
 	E_DEBUG("");
 	ix = 0;
-	check_volatile = swextopt_is_option_true(SW_E_check_volatile, G->optaM);
+	
+	if (strcmp(swlib_utilname_get(),  SWUTIL_NAME_SWVERIFY) == 0) {
+		check_volatile = swextopt_is_option_true(SW_E_check_volatile, G->optaM);
+	} else {
+		check_volatile = 0;
+	}
 
 	while ((name=swi_fl_get_path(fl, ix)) != NULL) {
 		if (G->devel_verboseM) {
@@ -3931,7 +3941,12 @@ swpl_bashin_detect(STROB * buf)
 	single command or compound command.  To get around shells
 	that don't do this, initially we pad with 1024 bytes of "####..."
 	which assumes that the shell is improperly gobbling only
-	1024 bytes at a time, then we exec the POSIX shell */
+	1024 bytes at a time, then we exec the POSIX shell
+	NOTE: the original ash shell gobbles 8kb per read() call,
+	IMHO this is terrible and does seem to be outside the mainstream
+	of traditional /bin/sh behaviour, systems with ash as /bin/sh are
+	broken as far as swbis interoperability is concerned. (Note, dash
+	has the read() size reduced, dash is supported by swbis) */
 
 
 	/* test for shell  with required POSIX feature
