@@ -56,7 +56,7 @@
 #define PROGNAME                "swremove"
 #define SW_UTILNAME             PROGNAME
 #define SWPROG_VERSION          SWREMOVE_VERSION
-#define WOPT_LAST		213   /* Highest option number */
+#define WOPT_LAST		237   /* Highest option number */
 
 static char progName[] = PROGNAME;
 static char * CHARTRUE = "True";
@@ -643,6 +643,32 @@ main(int argc, char **argv)
 		{"keep-volatile-files", 0, 0, 211},
 		{"cleansh", 0, 0, 212},
 		{"justdb", 0, 0, 213},
+		{"swbis_no_getconf", 		1, 0, 218},
+		{"swbis-no-getconf", 		1, 0, 218},
+		{"swbis_shell_command", 	1, 0, 219},
+		{"swbis-shell-command", 	1, 0, 219},
+		{"swbis_no_remote_kill", 	1, 0, 220},
+		{"swbis-no-remote-kill", 	1, 0, 220},
+		{"swbis_local_pax_write_command", 1, 0, 222},
+		{"swbis-local-pax-write-command", 1, 0, 222},
+		{"swbis_remote_pax_write_command", 1, 0, 223},
+		{"swbis-remote-pax-write-command", 1, 0, 223},
+		{"swbis_local_pax_read_command", 1, 0, 224},
+		{"swbis-local-pax-read-command", 1, 0, 224},
+		{"swbis_remote_pax_read_command", 1, 0, 225},
+		{"swbis-remote-pax-read-command", 1, 0, 225},
+		{"swbis_local_pax_remove_command", 1, 0, 226},
+		{"swbis-local-pax-remove-command", 1, 0, 226},
+		{"swbis_remote_pax_remove_command", 1, 0, 227},
+		{"swbis-remote-pax-remove-command", 1, 0, 227},
+		{"swbis_enforce_all_signatures", 	1, 0, 228},
+		{"swbis-enforce-all-signatures", 	1, 0, 228},
+		{"swbis_sig_level", 1, 0, 229},
+		{"swbis-sig-level", 1, 0, 229},
+		{"swbis_forward_agent", 	1, 0, 236},
+		{"swbis-forward-agent", 	1, 0, 236},
+		{"swbis_remove_volatile",	1, 0, 237},
+		{"swbis-remove-volatile",	1, 0, 237},
 		{0, 0, 0, 0}
              };
 
@@ -650,27 +676,18 @@ main(int argc, char **argv)
              {
 		{"enforce_scripts", 		1, 0, 216},
 		{"installed_software_catalog",	1, 0, 217},
-		{"swbis_no_getconf", 		1, 0, 218},
-		{"swbis_shell_command", 	1, 0, 219},
-		{"swbis_no_remote_kill", 	1, 0, 220},
-		{"swbis_local_pax_write_command", 1, 0, 222},
-		{"swbis_remote_pax_write_command", 1, 0, 223},
-		{"swbis_local_pax_read_command", 1, 0, 224},
-		{"swbis_remote_pax_read_command", 1, 0, 225},
-		{"swbis_local_pax_remove_command", 1, 0, 226},
-		{"swbis_remote_pax_remove_command", 1, 0, 227},
-		{"swbis_enforce_all_signatures", 	1, 0, 228},
-		{"swbis_sig_level", 1, 0, 229},
 		{"autoselect_dependencies", 	1, 0, 231},
 		{"distribution_target_directory", 1, 0, 232},
 		{"enforce_dependencies", 	1, 0, 233},
 		{"logfile", 			1, 0, 235},
-		{"swbis_forward_agent", 	1, 0, 236},
-		{"swbis_remove_volatile",	1, 0, 237},
 		{"verbose", 			1, 0, 240},
                {0, 0, 0, 0}
              };
 
+	/* -------------------------------------------------
+	-------------------------------------------------
+	-------------------------------------------------
+	-------------------------------------------------
 	struct option impl_extensions_long_options[] =
              {
 		{"noop", 0, 0, 154},
@@ -716,7 +733,11 @@ main(int argc, char **argv)
 		{"justdb", 0, 0, 213},
 		{0, 0, 0, 0}
              };
-	
+	------------------------------------------------------
+	------------------------------------------------------
+	------------------------------------------------------
+	------------------------------------------------------ */	
+
 	struct option std_long_options[] =
              {
 		{"distribution", 0, 0, 'd'},
@@ -1105,38 +1126,6 @@ gotoStandardOptions:
 			set_opta(opta, SW_E_logfile, eopt_logfile);
 			SWLIB_ALLOC_ASSERT(eopt_logfile != NULL);
 			break;
-		case 218:
-		case 219:
-		case 220:
-		case 222:
-		case 223:
-		case 224:
-		case 225:
-		case 226:
-		case 227:
-		case 228:
-		case 229:
-		case 236:
-		case 237:
-			optionname = getLongOptionNameFromValue(posix_extended_long_options , c);
-			SWLIB_ASSERT(optionname != NULL);
-			optionEnum = getEnumFromName(optionname, opta);
-			SWLIB_ASSERT(optionEnum > 0);
-			if (c == 229) {
-				/* Sanity check on sig_level */
-				int xres;
-				swlib_atoi(optarg, &xres);
-				if (xres != 0) {
-					sw_e_msg(G, "bad value detected for extended option: %s\n", optionname);
-					LCEXIT(1);
-				}
-			}
-			set_opta(opta, optionEnum, optarg);
-			if (swextopt_get_status()) {
-				sw_e_msg(G, "bad value detected for extended option: %s\n", optionname);
-				LCEXIT(1);
-			}
-			break;
 		default:
 			sw_e_msg(G, "error processing extended option\n");
 			sw_e_msg(G, "Try `swremove --help' for more information.\n");
@@ -1153,7 +1142,7 @@ gotoStandardOptions:
 		c = ugetopt_long(w_argc, 
 				cplob_get_list(w_arglist), 
 				"", 
-				impl_extensions_long_options, 
+				main_long_options, 
 				&w_option_index);
 		if (c == -1) break;
 	
@@ -1339,6 +1328,38 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 		case 213: /* WOPT_LAST */
 			G->g_justdbM = 1;
 			break;
+		case 218:
+		case 219:
+		case 220:
+		case 222:
+		case 223:
+		case 224:
+		case 225:
+		case 226:
+		case 227:
+		case 228:
+		case 229:
+		case 236:
+		case 237:
+			optionname = getLongOptionNameFromValue(main_long_options , c);
+			SWLIB_ASSERT(optionname != NULL);
+			optionEnum = getEnumFromName(optionname, opta);
+			SWLIB_ASSERT(optionEnum > 0);
+			if (c == 229) {
+				/* Sanity check on sig_level */
+				int xres;
+				swlib_atoi(optarg, &xres);
+				if (xres != 0) {
+					sw_e_msg(G, "bad value detected for extended option: %s\n", optionname);
+					LCEXIT(1);
+				}
+			}
+			set_opta(opta, optionEnum, optarg);
+			if (swextopt_get_status()) {
+				sw_e_msg(G, "bad value detected for extended option: %s\n", optionname);
+				LCEXIT(1);
+			}
+			break;
 		default:
 			sw_e_msg(G, "error processing implementation extension option : %s\n",
 				cplob_get_list(w_arglist)[w_option_index]);
@@ -1674,7 +1695,7 @@ gotoExtensionOptions:    /* Goto, Uhhg... */
 		target_path = swc_validate_targetpath(
 					target_nhops, 
 					tmpcharp, 
-					eopt_distribution_target_directory, cwd);
+					eopt_distribution_target_directory, cwd, "target");
 
 		SWLIB_ASSERT(target_path != NULL);
 		E_DEBUG2("target_path is [%s]", target_path);
