@@ -143,7 +143,9 @@ make_remove_command_script_fragment(GB * G, SWI * swi, STROB * buf, SWI_FILELIST
 					(int)swi_fl_is_volatile(fl, ix));
 		}
 
-		if (swi_fl_is_volatile(fl, ix))	{
+		if (G->g_justdbM == 1) {
+			action = 0;
+		} else if (swi_fl_is_volatile(fl, ix))	{
 			/* apply volatile policy */
 			if (do_remove_volatile == 1) {
 				/* keep going, just do it */
@@ -159,7 +161,6 @@ make_remove_command_script_fragment(GB * G, SWI * swi, STROB * buf, SWI_FILELIST
 			action = 1;
 		}
 
-
 		if (action == 1) {
 			/* remove it */
 			if (swi_fl_get_type(fl, ix) != DIRTYPE) {
