@@ -20,8 +20,4 @@
  */
 
 
-#include "swuser_config.h"
 #include "swexcat.h"
-
-// swPtrList<swExStruct> * swExCat::productsM;
-
