@@ -2,7 +2,7 @@
  */
 
 /*
- * Copyright (C) 2003,2008  James H. Lowe, Jr.  <jhlowe@acm.org>
+ * Copyright (C) 2003,2008,2009 James H. Lowe, Jr.  <jhlowe@acm.org>
  *
  * COPYING TERMS AND CONDITIONS
  * This program is free software; you can redistribute it and/or modify
@@ -343,11 +343,13 @@ class swExFileset: public swObjFiles_i
 		swDefinitionFile * info;	
 		swDefinition * swdef;
 		swDefinition * stats_swdef;
+		char * filetype;
 		char * path;
 		char * value;
 		int ofd;
 		int preview_fd;
-		intmax_t ret;
+		int ret;
+		intmax_t retval;
 		int skip;
 		int do_adjunct = 0;
 		swPackageFile * archiver;
@@ -432,19 +434,24 @@ class swExFileset: public swObjFiles_i
 			//
 			// Write the archive member.
 			//
-			ret = 0;
+			retval = 0;
 			skip = 0;
 			SWEXFILESET_DEBUG2("Processing [%s]", path);
+			filetype = swdef->find(SW_A_type);
+			if (!filetype) {
+				setErrorCode(12303, NULL);
+				return;
+			}
+
+			if (*filetype != SW_ITYPE_f && getStoreRegTypeOnly() ) {
+				skip = 1;
+			}
+
 			if (do_adjunct) {
 				//
 				// Skip symlinks.
 				//
-				if ((value=swdef->find(SW_A_type)) == NULL)  {
-					fprintf(stderr,
-						"file type missing for %s\n",
-						strob_str(tmp));
-				}
-				if (value && *value == 's') {
+				if (*filetype == SW_ITYPE_s) {
 					//
 					// skip it.
 					//
@@ -452,6 +459,44 @@ class swExFileset: public swObjFiles_i
 					;;
 				}
 			}
+
+			//
+			// Check that if a special device file, the minor/major can fit
+			// in a standard tar header.
+			//
+
+			if (*filetype == SW_ITYPE_c || *filetype == SW_ITYPE_b) {
+				char * xp;
+				int xret;
+				int xresult;
+				struct new_cpio_header * file_hdr;
+
+				file_hdr = taru_make_header();
+				xp = swdef->find(SW_A_major);
+				file_hdr->c_rdev_maj = swlib_atoul(xp, &xresult);
+				if (xresult) setErrorCode(12306, NULL);
+				xp = swdef->find(SW_A_minor);
+				file_hdr->c_rdev_min = swlib_atoul(xp, &xresult);
+				if (xresult) setErrorCode(12307, NULL);
+				assertNoErrorCondition(41);
+				xret = taru_check_devno_for_tar(file_hdr);
+				if (xret) {
+					// can't represent in seven (7) octal digits
+					skip = 1;
+					fprintf(stderr,
+       	                                	"%s: device number too large, omitting from storage section: %s\n",
+						swlib_utilname_get(), path);
+				} else {
+					xret = taru_check_devno_for_system(file_hdr);
+					if (xret) {
+						fprintf(stderr,
+       		                                	"%s: warning: device number may be too large for this system: %s\n",
+							swlib_utilname_get(), path);
+					}
+				}
+				taru_free_header(file_hdr);
+			}
+
 			stats_swdef = swdef;
 			if (swdef->get_storage_status() == SWDEF_STATUS_IGN) {
 				skip = 1;
@@ -497,10 +542,10 @@ class swExFileset: public swObjFiles_i
 			// swdef->write_fd_debug(2, "");
 			if (skip) {
 				// archiver->xFormat_set_ofd(getNullFd());
-				// ret = archiver->xFormat_write_file(swdef, strob_str(tmp));
+				// retval = archiver->xFormat_write_file(swdef, strob_str(tmp));
 				// archiver->xFormat_set_ofd(ofd);
 				SWEXFILESET_DEBUG2("skipping [%s]", path);
-				ret = 0;
+				retval = 0;
 			} else {
 				SWEXFILESET_DEBUG2("writing [%s]", path);
 				swlib_process_hex_escapes(strob_str(tmp));
@@ -527,18 +572,18 @@ class swExFileset: public swObjFiles_i
 				SWEXFILESET_DEBUG2("<<<<< writing [%s]", tmp->str_);
 				/* Final sanity check on the archive path */
 				if (strstr(strob_str(tmp), "../")) {
-					ret = -1;
+					retval = -1;
 				} else {
-					ret = archiver->xFormat_write_file(stats_swdef, strob_str(tmp));
+					retval = archiver->xFormat_write_file(stats_swdef, strob_str(tmp));
 				}
 			} 
 			skip = 0;	
 			
-			if (ret < 0) {
+			if (retval < 0) {
 				fprintf(stderr,
-					"%s: error writing archive member for ( %s ) ret=%s\n",
-					swlib_utilname_get(), strob_str(tmp), swlib_imaxtostr(ret, NULL));
-				setErrorCode(12303, NULL);
+					"%s: error writing archive member, status=%s, name=%s\n",
+					swlib_utilname_get(), swlib_imaxtostr(retval, NULL), strob_str(tmp));
+				setErrorCode(12304, NULL);
 				return;
 			}
 	skipdup:;
