@@ -23,9 +23,10 @@
 #ifndef swobjfiles_i_hxx
 #define swobjfiles_i_hxx
 
-extern "C" {
 #define FILENEEDDEBUG 1
 #undef FILENEEDDEBUG
+
+extern "C" {
 #include "swuser_config.h"
 }
 
@@ -63,12 +64,16 @@ extern "C" {
 
 #define INFO_SIZE_BLANK	"\040\040\040\040\040\040\040\040"  // Eight (8) Spaces
 
-/*
+#ifdef FILENEEDDEBUG
 #define E_DEBUG(format) SWBISERROR("DEBUG", format)
 #define E_DEBUG2(format, arg) SWBISERROR2("DEBUG", format, arg)
 #define E_DEBUG3(format, arg, arg1) \
  			SWBISERROR3("DEBUG", format, arg, arg1)
-*/
+#else
+#define E_DEBUG(format)
+#define E_DEBUG2(format, arg)
+#define E_DEBUG3(format, arg, arg1)
+#endif
 
 class swObjFiles;
 class swObjFiles_i:  public swExStruct_i
@@ -506,6 +511,20 @@ class swObjFiles_i:  public swExStruct_i
 				path = NULL;
 			}
 
+			if (path == NULL) {
+				//
+				// This may happen when a file object is specified as a
+				// file definition using the 'source' attribute alone.
+				//
+				swat = (static_cast<swDefinition*>(swmd))->findAttribute(SW_A_source);
+				if (swat) {
+					path = swat->get_value(NULL);
+					E_DEBUG2("path=[%s]", path);
+				} else {
+					path = NULL;
+				}
+			}
+
 			//
 			// Now check for duplicate file definitions as required
 			// by the POSIX spec.
@@ -518,9 +537,10 @@ class swObjFiles_i:  public swExStruct_i
 				get_opta_array() == NULL ||
 				::swextopt_is_option_true(SW_E_swbis_check_duplicates, get_opta_array())
 			) {
-				E_DEBUG("finding duplicates");
+				E_DEBUG2("finding duplicates of pathname [%s]", path);
 				did_find_duplicate = check_for_storage_section_duplicates(filedeflist, pathlist, path, basenames);
 			} else {
+				E_DEBUG2("Not even looking for duplicates for pathname [%s]", path);
 				did_find_duplicate = 0;
 			}
 			swmd_def = static_cast<swDefinition*>(swmd);
@@ -538,8 +558,12 @@ class swObjFiles_i:  public swExStruct_i
 				// Here, (swDefinition*)(swmd) represents the current last
 				// duplicate found so far.
 				//
-				E_DEBUG("setting storage status SWDEF_STATUS_DUP");
+				E_DEBUG("Duplicate found");
+				E_DEBUG2("setting storage status SWDEF_STATUS_DUP for %s", path);
 				swmd_def->set_storage_status(SWDEF_STATUS_DUP);
+			} else {
+				;
+				E_DEBUG("Duplicate *NOT* found");
 			}	
 
 			swlib_doif_writef(swlib_get_verbose_level(), SWPACKAGE_VERBOSE_V3, NULL, swfdio_get(STDERR_FILENO),
@@ -763,6 +787,7 @@ class swObjFiles_i:  public swExStruct_i
 		int ret;
 		swDefinition * inext;
 		swINFO * info = getInfo();
+		char * type;
 		char * complete_value;
 		SWVARFS * swvarfs = getSwvarfs();
 		swPackageFile * archiver = getArchiver();
@@ -787,7 +812,11 @@ class swObjFiles_i:  public swExStruct_i
 				// Add the file stats.
 				//
 				noesc_source = inext->find(SW_A_source);
-				SWLIB_ASSERT(noesc_source != NULL);
+				if (noesc_source == NULL) {
+					fprintf(stderr, "swpackage: source attribute is missing\n");
+					SWLIB_ASSERT(noesc_source != NULL);
+				}	
+
 				if (strstr(noesc_source, "\\x")) {
 					dupsource = strdup(noesc_source);
 					swlib_process_hex_escapes(dupsource);
@@ -798,6 +827,11 @@ class swObjFiles_i:  public swExStruct_i
 					did_dup = 0;
 				}
 
+				type = inext->find(SW_A_type);
+				if (type && (*type == SW_ITYPE_b || *type == SW_ITYPE_c)) {
+					check_device_files_for_no_stat(inext);
+				}
+
 				ret = archiver->apply_file_stats(inext, swvarfs, dupsource, cksumflags);
 				if (did_dup) free(dupsource);
 
@@ -1413,6 +1447,19 @@ class swObjFiles_i:  public swExStruct_i
 
    private:  
 
+	void check_device_files_for_no_stat(swDefinition * inext) {
+		if (
+			inext->find(SW_A_mode) &&
+			(inext->find(SW_A_owner) || inext->find(SW_A_uid)) &&
+			(inext->find(SW_A_group) || inext->find(SW_A_gid)) &&
+			inext->find(SW_A_major) &&
+			inext->find(SW_A_minor) &&
+			1
+		) {
+			inext->set_no_stat(1);
+		}
+	}
+
 	int
 	check_control_file_duplicates(STRAR * pathlist, char * incoming_path)
 	{
@@ -1444,6 +1491,7 @@ class swObjFiles_i:  public swExStruct_i
 		char * tmpname;
 
 		if (!incoming_path) return 0;
+		E_DEBUG2("Entering: Looking for %s", incoming_path);
 
 		//
 		//  The scheme is to mark duplicates.
@@ -1486,6 +1534,7 @@ class swObjFiles_i:  public swExStruct_i
 		//
 		// Only attempt this optimization if we get a clean basename.
 		//
+		E_DEBUG("");
 		if (1 && 
 			incoming_base_name && *incoming_base_name != '/'
 		) {
@@ -1497,11 +1546,13 @@ class swObjFiles_i:  public swExStruct_i
 			}
 		}
 
+		E_DEBUG("");
 		current_path_p = path_array;
 		while(*current_path_p) {
-			E_DEBUG3("current_path :: incoming_path  [%s] :: [%s]", *current_path_p, incoming_path);
+			E_DEBUG3("checking for duplicate: current_path :: incoming_path  [%s] :: [%s]", *current_path_p, incoming_path);
 			ret = swlib_dir_compare(*current_path_p, incoming_path, SWC_FC_NOAB);
 			if (ret == 0) {
+				E_DEBUG2("********** Got duplicate ************* %s", *current_path_p);
 				//
 				// Got duplicate.
 				//
@@ -1517,6 +1568,7 @@ class swObjFiles_i:  public swExStruct_i
 
 				// DEBUG duplicate_def->write_fd(2);
 
+				E_DEBUG("Duplicate");
 				fprintf(stderr, "swpackage: warning: duplicate file definition: %s\n", incoming_path);
 				if (duplicate_def->get_storage_status() == SWDEF_STATUS_DUP) {
 					E_DEBUG("GOT ONE: 1");
@@ -1543,8 +1595,7 @@ class swObjFiles_i:  public swExStruct_i
 				}
 				
 			} else {
-				E_DEBUG("");
-				// fprintf(stderr, "eraseme swpackage: no duplicate here [%s] [%s]\n", incoming_path, *current_path_p);
+				E_DEBUG3("**** [%s] is not a duplicate of [%s]", *current_path_p, incoming_path);
 				;
 			}
 			index ++;
