@@ -36,7 +36,7 @@ char * swDefControlFile::getPathAttribute(void)
 {
 	char * path = find(SW_A_path);
 	if (!path) {
-		char * source = find("source");
+		char * source = find(SW_A_source);
 		assert(source);
 		char * basename = ::strrchr(source,'/');
 		if (!basename) {
@@ -116,13 +116,11 @@ swDefControlFile::set_tag_attribute(void)
 	//
 	// Section 5.2.10  Lines 637-638
 	//
-	source = find("source");
+	source = find(SW_A_source);
 	
-	//set_path_attribute(source);
 	path = find(SW_A_path);
 	swlib_basename(tmp, path);
 
 	add(SW_A_tag, strob_str(tmp));
 	strob_close(tmp);
 }
-
