@@ -441,7 +441,7 @@ public: // =====================================================================
 						fprintf(stderr, "<<<<<<<\n");
 					#endif
 					/* set_start_index(psf, priorFile); */
-					prior_file->merge(swdefFormedM, 0);
+					prior_file->merge(swdefFormedM, 0, 1 /* do replace */);
 					#ifdef SWEXTDEFNEEDDEBUG
 						fprintf(stderr, "after merge>>>>>\n");
 						prior_file->write_fd(2);
@@ -668,7 +668,7 @@ public: // =====================================================================
 				//
 				// Sanity check
 				// 
-				fprintf(stderr,"swpackage: error: path attribute not found in processExcludes().\n");
+				fprintf(stderr,"swpackage: warning: source attribute not found\n");
 				return -1;
 			}
 
@@ -744,7 +744,7 @@ public: // =====================================================================
 			//
 			// It can be a control_file extended definition.
 			//
-			int gr = swstructdef::return_entry_group(swstructdef::return_entry_index("product", keyword));
+			int gr = swstructdef::return_entry_group(swstructdef::return_entry_index(SW_A_product, keyword));
 			if (strcmp(keyword, "control_file") == 0 || gr == swstructdef::CONTROLFILE_EXT) {
 				if ((retval = processExtendedControl_file(keyword, value, swdef)) == 0) { 
 					assert(swdefFormedM);
@@ -868,7 +868,7 @@ private: // ================================================================
 				prior_file->write_fd(2);
 				fprintf(stderr, "<<<<<<<\n");
 			#endif
-			prior_file->merge(swdef, 1 /* merge unconditionally */);
+			prior_file->merge(swdef, 1/*merge unconditionally*/, 1 /* do replace*/);
 		} else {
 			psf->swdeffile_list_add(swdef);
 			/* set_start_index(psf, swdefFormedM); */
@@ -1260,8 +1260,8 @@ private: // ================================================================
 				// if not a fileset but don't quit.
 				//
 				if(
-					strcmp("fileset", swdef->get_keyword()) != 0 &&
-					strcmp("control_file", swdef->get_keyword()) != 0
+					strcmp(SW_A_fileset, swdef->get_keyword()) != 0 &&
+					strcmp(SW_A_control_file, swdef->get_keyword()) != 0
 				) {
 					fprintf(stderr,
 					"swpackage: Internal Exception: warning: Non file object found in list in find_same_prior_file() %s.\n",
