@@ -59,7 +59,7 @@ extern "C" {
 #define SWMETADATA_DEBUG3(arg, arg1, arg2)
 #endif
 
-#define SWFILE_DO_CKSUM   (1 << 0)	// Do create Posix cksum
+#define SWFILE_DO_CKSUM   (1 << 0)	// Do create POSIX cksum
 #define SWFILE_DO_FILE_DIGESTS  (1 << 1)	// Do create md5 digest.
 #define SWFILE_DO_FILE_DIGESTS_SHA2  (1 << 2)	// Do create md5 digest.
 #define SWBIS_NO_STAT_INDICATOR "\x1C"    // FS source names that begin with this are not lstat'ed., Internal use only.
@@ -174,7 +174,7 @@ class swMetaData
 
 	virtual int list_add_if_new (swMetaData * newnode);
 	virtual void  list_replace (swMetaData * newnode);
-    
+   	virtual void list_replace_if_not_explicitly_set(swMetaData * swmd); 
 	virtual void list_insert (swMetaData * header, swMetaData * newnode);
 
 	virtual void set_ino(int off);       //identifying serial number, constant.
