@@ -777,9 +777,11 @@ class swPackageFile :  public swAttribute
 				tmp_control_path = (STROB*)NULL;
 			}
 
-			xFormat_apply_swdef_stats(swdef, source,
+			ret = xFormat_apply_swdef_stats(swdef, source,
 				1 /*logical ON, means vremoved attr. will be ignored*/,
 				tmp_control_path);
+			if (ret)
+				return -4;	
 			
 			swfile_set_package_filename(package_path);
 			source = swdef->find(SW_A_source); // This line fixed a core dump.
@@ -1114,7 +1116,8 @@ class swPackageFile :  public swAttribute
 
 	int xFormat_apply_swdef_stats(swDefinition * swdef, char * source,
 			int logical_find, STROB * tmp_control_path) {
-		int ret = 0;
+		int ret;
+		int retval = 0;
 		char * type;
 		char * value;
 		char * value2;
@@ -1147,7 +1150,8 @@ class swPackageFile :  public swAttribute
 		//
 			
 		if ((value=swdef->find(SW_A_mtime))) {
-			taru_datoul(value, &timeval);
+			ret = taru_datoul(value, &timeval);
+			if (ret == 2) retval = 3;
 			xFormat_set_mtime((time_t)timeval);
 		}
 		else {
@@ -1181,7 +1185,8 @@ class swPackageFile :  public swAttribute
 					SWPACKAGEFILE_DEBUG("Setting user name");
 					xFormat_set_username(value);
 				}
-				taru_datoul(value2, &uid);
+				ret = taru_datoul(value2, &uid);
+				if (ret == 2) retval = 3;
 				xFormat_set_uid((uid_t)uid);
 				xFormat_set_sys_db_u_policy(TARU_C_BY_UNONE);
 			}
@@ -1196,7 +1201,8 @@ class swPackageFile :  public swAttribute
 				//
 				SWPACKAGEFILE_DEBUG("No user name, but has uid");
 				xFormat_set_sys_db_u_policy(TARU_C_BY_UID);
-				taru_datoul(value2, &uid);
+				ret = taru_datoul(value2, &uid);
+				if (ret == 2) retval = 3;
 				xFormat_set_uid((uid_t)uid);
 			} else {
 				//
@@ -1234,7 +1240,8 @@ class swPackageFile :  public swAttribute
 					SWPACKAGEFILE_DEBUG("Setting group name");
 					xFormat_set_groupname(value);
 				}
-				taru_datoul(value2, &gid);
+				ret = taru_datoul(value2, &gid);
+				if (ret == 2) retval = 3;
 				xFormat_set_gid((gid_t)gid);
 				xFormat_set_sys_db_g_policy(TARU_C_BY_GNONE);
 			}
@@ -1249,7 +1256,8 @@ class swPackageFile :  public swAttribute
 				//
 				SWPACKAGEFILE_DEBUG("No group name, but has gid");
 				xFormat_set_sys_db_g_policy(TARU_C_BY_GID);
-				taru_datoul(value2, &gid);
+				ret = taru_datoul(value2, &gid);
+				if (ret == 2) retval = 3;
 				xFormat_set_gid((gid_t)gid);
 			} else {
 				//
@@ -1281,7 +1289,8 @@ class swPackageFile :  public swAttribute
 		}
 		
 		if ((value=swdef->find(SW_A_minor))) {
-			taru_datoul(value, &devnum);
+			ret = taru_datoul(value, &devnum);
+			if (ret == 2) retval = 3;
 			xFormat_set_devminor((dev_t)devnum);
 		}
 		else {
@@ -1289,7 +1298,8 @@ class swPackageFile :  public swAttribute
 		}
 		
 		if ((value=swdef->find(SW_A_major))) {
-			taru_datoul(value, &devnum);
+			ret = taru_datoul(value, &devnum);
+			if (ret == 2) retval = 3;
 			xFormat_set_devmajor((dev_t)devnum);
 		}
 		else {
@@ -1297,12 +1307,14 @@ class swPackageFile :  public swAttribute
 		}
 
 		if ((value=swdef->findPhysical("_ino"))) {
-			taru_datoul(value, &devnum);
+			ret = taru_datoul(value, &devnum);
+			if (ret == 2) retval = 3;
 			xFormat_set_inode((ino_t)devnum);
 		}
 		
 		if ((value=swdef->findPhysical("_nlink"))) {
-			taru_datoul(value, &devnum);
+			ret = taru_datoul(value, &devnum);
+			if (ret) retval = 3;
 			xFormat_set_nlink(devnum);
 		}
 
@@ -1341,7 +1353,7 @@ class swPackageFile :  public swAttribute
 					}
 					xFormat_set_linkname(value);
 				} else {
-					ret = 1;
+					retval = 1;
 					fprintf(stderr, "link_source missing for file %s\n", source);
 				}
 			} else {
@@ -1353,7 +1365,7 @@ class swPackageFile :  public swAttribute
 					sscanf(value, "%lu", &dev);
 					xFormat_set_devminor((dev_t)dev);
 				} else {
-					ret = 1;
+					retval = 1;
 					fprintf(stderr, "minor device number missing for file %s\n", source);
 				}
 	
@@ -1361,7 +1373,7 @@ class swPackageFile :  public swAttribute
 					sscanf(value, "%lu", &dev);
 					xFormat_set_devmajor((dev_t)dev);
 				} else {
-					ret = 2;
+					retval = 2;
 					fprintf(stderr, "major device number missing for file %s\n", source);
 				}
 			}
@@ -1371,7 +1383,7 @@ class swPackageFile :  public swAttribute
 		}
 
 		set_find_mode_logical(0);	
-		return ret;
+		return retval;
 	}
 	
 
