@@ -56,6 +56,7 @@ swDefinition * swPSF::makeDefinition (char * parser_line, int * retval) {
 		!::strcmp(keyword, SW_A_bundle) ||
 		0
 	) {
+		E_DEBUG("swextM->reset()");
 		swextM->reset();		
 	}
 
@@ -80,6 +81,7 @@ swDefinition * swPSF::makeDefinition (char * parser_line, int * retval) {
 		!::strcmp(keyword, SW_A_bundle) ||
 		0
 	) {
+		E_DEBUG("");
 		swdefM = static_cast<swDefinition*>(swdef);
 	}	
 
@@ -92,6 +94,7 @@ swDefinition * swPSF::makeDefinition (char * parser_line, int * retval) {
 		!::strcmp(keyword, SW_A_fileset) ||
 		0
 	) {
+		E_DEBUG("");
 		swextM->set_fileset_start_index(this);
 	}
 
@@ -103,6 +106,7 @@ swDefinition * swPSF::makeDefinition (char * parser_line, int * retval) {
 			//
 			// Set the default filePermissions.
 			//
+			E_DEBUG("setting default permissions");
 			swextM->addDefaultFilePermissions(static_cast<swDefinition*>(swdef)); // FIXME, static down cast.
 		}
 	}
@@ -138,6 +142,7 @@ swMetaData * swPSF::generate_attribute_list(int at_level, int *retvalp) {
 		E_DEBUG2("%s", parser_line);
 		switch(u_type) {	
 			case swstructdef::sdf_attribute_kw:
+				E_DEBUG("case swstructdef::sdf_attribute_kw:");
 				if (swheaderline_get_keyword(parser_line)) {
 					//
 					// seek back since swAttribute operates on the
@@ -170,6 +175,7 @@ swMetaData * swPSF::generate_attribute_list(int at_level, int *retvalp) {
 				}
 				break;
 			case swstructdef::sdf_extended_kw:
+				E_DEBUG("case swstructdef::sdf_extended_kw");
 				if(!nloops) {
 					E_DEBUG2("running processExtendedDefinition on %s", parser_line);
 					if (swextM->processExtendedDefinition(parser_line, this, swdefM)) {
@@ -191,6 +197,7 @@ swMetaData * swPSF::generate_attribute_list(int at_level, int *retvalp) {
 				break;
 			case swstructdef::sdf_object_kw:
 			default:
+				E_DEBUG("case swstructdef::sdf_object_kw");
 				uxfio_lseek(get_mem_fd(), offset, SEEK_SET);
 				u_break=1;
 				break;
