@@ -938,3 +938,17 @@ shcmd_set_lowest_close_fd(SHCMD * cmd, int fd)
 {
 	cmd->close_all_fd_ = fd;
 }
+
+SHCMD *
+shcmd_get_last_command(SHCMD ** cmdvec)
+{
+	SHCMD ** v;
+	SHCMD * last;
+	last = NULL;
+	v = cmdvec;
+	while (*v) {
+		last = *v;
+		v++;
+	}
+	return last;
+}
