@@ -6,7 +6,7 @@
    COPYING TERMS AND CONDITIONS:
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,7 +14,7 @@
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #define FILENEEDDEBUG 1
 #undef FILENEEDDEBUG
@@ -38,6 +38,9 @@ extern struct swEvents eventsArray[];
 static struct swEvents * g_evnt = eventsArray;
 */
 
+static int s_verboseM  = SWC_VERBOSE_4;
+
+
 #define SWEVENT_LV	1
 #define SWEVENT_LV6	6
 #define SWI_EVENT	1  /* Is an event that takes place in swi.c */
@@ -45,6 +48,9 @@ static struct swEvents * g_evnt = eventsArray;
 				/* -SW_ERROR means event is always an error */
 static struct swEvents eventsArray[] = {
 {"", 0, 0, "", 0, SW_NOTE},
+{"SW_ILLEGAL_STATE_TRANSITION",		1, 	SWEVENT_LV, "", 1, SW_ERROR},
+{"SW_BAD_SESSION_CONTEXT",		2, 	SWEVENT_LV, "", 1, SW_ERROR},
+{"SW_ILLEGAL_OPTION",			3, 	SWEVENT_LV, "", 1, SW_ERROR},
 {"SW_ACCESS_DENIED", 			4, 	SWEVENT_LV, "", 1, SW_ERROR},
 {"SW_MEMORY_ERROR", 			5,	SWEVENT_LV, "", 1, -SW_ERROR},
 {"SW_RESOURCE_ERROR", 			6,	SWEVENT_LV, "", 1, -SW_ERROR},
@@ -56,18 +62,32 @@ static struct swEvents eventsArray[] = {
 {"SW_SESSION_BEGINS", 			28, 	SWEVENT_LV, "", 0, SW_NOTE},
 {"SW_SESSION_ENDS", 			29, 	SWEVENT_LV, "", 0, SW_ERROR},
 {"SW_CONNECTION_LIMIT_EXCEEDED", 	30,	SWEVENT_LV, "", 0, -SW_ERROR}, 
-{"SW_SOC_DOES_NOT_EXIST", 		31, 	1, 	    "", 0, -SW_ERROR},
+{"SW_SOC_DOES_NOT_EXIST", 		31, 	SWEVENT_LV, "", 0, -SW_ERROR},
 {"SW_SOC_IS_CORRUPT",	 		32,	SWEVENT_LV, "", 0, SW_ERROR},
 {"SW_SOC_CREATED", 			34, 	1,          "", 0, SW_NOTE},
+{"SW_CONFLICTING_SESSION_IN_PROGRESS", 	35, 	1,          "", 0, SW_ERROR},
+{"SW_SOC_LOCK_FAILURE",			36, 	1,          "", 0, SW_ERROR},
+{"SW_SOC_IS_READ_ONLY",			37, 	1,          "", 0, SW_ERROR},
 {"SW_SOC_IS_REMOTE", 			38, 	1,          "", 0, SW_NOTE},
 {"SW_SOC_IS_SERIAL", 			40, 	1,          "", 0, SW_NOTE},
+{"SW_SOC_INCORRECT_TYPE", 		41, 	1,          "", 0, SW_ERROR},
+{"SW_CANNOT_OPEN_LOGFILE", 		42, 	1,          "", 0, SW_ERROR},
 {"SW_SOC_AMBIGUOUS_TYPE",		49, 	SWEVENT_LV, "", 0, -SW_NOTE},
 {"SW_ANALYSIS_BEGINS", 			52, 	SWEVENT_LV, "", 1, SW_NOTE},
 {"SW_ANALYSIS_ENDS", 			53, 	SWEVENT_LV, "", 1, SW_NOTE},
+{"SW_EXREQUISITE_EXCLUDE",		56,	SWEVENT_LV, "", 1, SW_NOTE},
 {"SW_CHECK_SCRIPT_EXCLUDE",		57,	SWEVENT_LV, "", 1, SW_NOTE},
 {"SW_CONFIGURE_EXCLUDE", 		58,	SWEVENT_LV, "", 1, SW_NOTE},
-{"SW_SOURCE_ACCESS_ERROR", 		60, 	1, ": File not found.", 0, SW_ERROR},
-{"SW_HIGHER_REVISION_INSTALLED", 	67,	SWEVENT_LV, "", 1, SW_NOTE},
+{"SW_SELECTION_IS_CORRUPT", 		59,	SWEVENT_LV, "", 1, SW_ERROR},
+{"SW_SOURCE_ACCESS_ERROR", 		60, 	SWEVENT_LV, ": File not found.", 0, SW_ERROR},
+{"SW_SELECTION_NOT_FOUND", 		62, 	SWEVENT_LV, "", 0, SW_ERROR},
+{"SW_SELECTION_NOT_FOUND_RELATED", 	63, 	SWEVENT_LV, "", 0, SW_ERROR},
+{"SW_SELECTION_NOT_FOUND_AMBIG", 	64, 	SWEVENT_LV, "", 0, SW_ERROR},
+{"SW_FILESYSTEMS_NOT_MOUNTED", 		65, 	SWEVENT_LV, "", 0, SW_ERROR},
+{"SW_FILESYSTEMS_MORE_MOUNTED", 	66, 	SWEVENT_LV, "", 0, SW_ERROR},
+{"SW_HIGHER_REVISION_INSTALLED", 	67, 	SWEVENT_LV, "", 0, SW_ERROR},
+{"SW_NEW_MULTIPLE_VERSION", 		68, 	SWEVENT_LV, "", 0, SW_ERROR},
+{"SW_EXISTING_MULTIPLE_VERSION", 	69, 	SWEVENT_LV, "", 0, SW_ERROR},
 {"SW_DEPENDENCY_NOT_MET",		70,	SWEVENT_LV, "", 1, SW_ERROR},
 {"SW_NOT_COMPATIBLE",			71,	SWEVENT_LV, "", 1, SW_ERROR},
 {"SW_CHECK_SCRIPT_WARNING",		72,	SWEVENT_LV, "", 1, SW_WARNING},
@@ -101,6 +121,15 @@ static struct swEvents eventsArray[] = {
 {"SW_SOURCE_ACCESS_BEGINS", 		260, 	SWEVENT_LV, "", 0, SW_NOTE},
 {"SW_SOURCE_ACCESS_ENDS", 		261, 	SWEVENT_LV, "", 0, SW_ERROR},
 {"SW_CONTROL_SCRIPT_ENDS",		262,	SWEVENT_LV, "", 1, SW_NOTE},
+{"SW_SOC_LOCK_CREATED",			263,	SWEVENT_LV, "", 1, SW_ERROR},
+{"SW_SOC_LOCK_REMOVED",			264,	SWEVENT_LV, "", 1, SW_ERROR},
+{"SW_SELECTION_EXECUTION_BEGINS",	265,	SWEVENT_LV, "", 0, SW_NOTE},
+{"SW_SELECTION_EXECUTION_ENDS",		266,	SWEVENT_LV, "", 0, SW_ERROR},
+{"SW_ISC_INTEGRITY_CONFIRMED",		267,	SWEVENT_LV, "", 0, SW_ERROR},
+{"SW_ISC_INTEGRITY_NOT_CONFIRMED",	268,	SWEVENT_LV, "", 0, SW_ERROR},
+{"SW_SPECIAL_MODE_BEGINS",		269,	SWEVENT_LV, "", 0, SW_ERROR},
+{"SW_SOC_INTEGRITY_CONFIRMED",		270,	SWEVENT_LV, "", 0, SW_ERROR},
+{"SW_SOC_INTEGRITY_NOT_CONFIRMED",	271,	SWEVENT_LV, "", 0, SW_ERROR},
 
 {"SWI_PRODUCT_SCRIPT_ENDS", 		280, 	SWEVENT_LV, "", 1, SW_NOTE},
 {"SWI_FILESET_SCRIPT_ENDS", 		281, 	SWEVENT_LV, "", 1, SW_NOTE},
@@ -121,7 +150,9 @@ static struct swEvents eventsArray[] = {
 {"SWI_ATTRIBUTE",			315,	SWEVENT_LV, "", 1, SW_NOTE},
 {"SWI_GROUP_BEGINS",			316,	SWEVENT_LV, "", 1, SW_NOTE},
 {"SWI_GROUP_ENDS",			317,	SWEVENT_LV, "", 1, SW_NOTE},
-{"", -1, 0, "", 0, SW_NOTE}
+{"SWI_TASK_CTS",			318,	SWEVENT_LV6, "", 1, SW_NOTE},
+{"SWI_MAIN_SCRIPT_ENDS",		319,	SWEVENT_LV6, "", 1, SW_NOTE},
+{"<_nil_>", -1, 0, "", 0, SW_NOTE}
 };
 
 static
@@ -168,12 +199,11 @@ get_struct_by_value(int value, struct swEvents * evnt)
 	return NULL;
 }
 
-static
 char *
-swevent_code(struct swEvents * evnt, int value)
+swevent_code(int value)
 {
 	struct swEvents * eop;
-	eop = evnt;
+	eop = swevent_get_events_array();
 	while (eop->valueM != -1) {
 		if (eop->valueM == value)  {
 			return eop->codeM;
@@ -256,20 +286,26 @@ char *
 swevent_message(struct swEvents * evnt, STROB * buf, int value, char * host, 
 				char * loc, char * msg, int verbose_level)
 {
-	if (verbose_level >= 4)
+	if (verbose_level >= s_verboseM)
 		strob_sprintf(buf, 0, 
 				"%s: %s on %s host `hostname` at line $LINENO: %s",
 			 		swlib_utilname_get(), 
-					swevent_code(evnt, value), 
+					swevent_code(value), 
 					loc, msg); 
 	else
 		strob_sprintf(buf, 0, "%s: %s on %s host `hostname`: %s", 
 				swlib_utilname_get(), 
-				swevent_code(evnt, value),
+				swevent_code(value),
 				 loc, msg); 
 	return strob_str(buf);
 }
 
+void
+swevent_set_verbose(int v)
+{
+	s_verboseM  = v;
+}
+
 char *
 swevent_shell_echo(int to_fd, int verbose_level, 
 			char * loc, int value, char * host, char * msg)
@@ -443,7 +479,7 @@ swevent_write_rpsh_event(int fd, char * event_line, int len)
 	/*
 	fprintf(stderr, "JL writing [%s]\n", strob_str(tmp)); 
 	*/
-	ret = write(fd, strob_str(tmp), strob_strlen(tmp));
+	ret = uxfio_unix_safe_write(fd, strob_str(tmp), strob_strlen(tmp));
 	if (ret < 0 || ret != (int)strob_strlen(tmp)) {
 		fprintf(stderr, "swevent_write_rpsh_event: error: write: ret=%d fd=%d %s\n",
 				ret, fd, strerror(errno));
