@@ -59,6 +59,42 @@ static char * utilnames[] = {
 	"",            /* SWC_U_X  (1 << 9) */
 	NULL };
 
+static
+int
+i_is_value_false(char * s)
+{
+	if (
+		s == NULL ||
+		(
+			strcasecmp(s, "false") == 0 ||
+			strcasecmp(s, "no") == 0 ||
+			strcasecmp(s, "n") == 0 ||
+			0
+		)
+	) {
+		return 1;
+	}
+	return 0;
+}
+
+static
+int
+i_is_value_true(char * s)
+{
+	if (
+		s != NULL &&
+		(
+			strcasecmp(s, "true") == 0 ||
+			strcasecmp(s, "yes") == 0 ||
+			strcasecmp(s, "y") == 0 ||
+			0
+		)
+	) {
+		return 1;
+	}
+	return 0;
+}
+
 static
 int
 find_pow(int flag)
@@ -73,6 +109,19 @@ find_pow(int flag)
 	return i;
 }
 
+static
+int 
+i_getEnumFromName(char * optionname, struct extendedOptions * peop)
+{
+	struct extendedOptions * eop;
+	eop = peop;
+	while (eop->optionNameM && strcmp(eop->optionNameM, optionname)) {
+		eop ++;
+	}
+	if (eop->optionNameM == NULL) return -1;
+	return (((char*)eop) - (char*)peop) / sizeof(struct extendedOptions);
+}
+
 static
 int
 check_applicability(struct extendedOptions * opta, enum eOpts nopt)
@@ -228,31 +277,29 @@ swextopt_write_session_options(STROB * buf, struct extendedOptions * opta, int S
 int
 swextopt_is_value_false(char * s)
 {
-	if (
-		s == NULL ||
-		(
-			strcasecmp(s, "false") == 0 ||
-			strcasecmp(s, "no") == 0 ||
-			strcasecmp(s, "n") == 0 ||
-			0
-		)
-	) return 1;
-	return 0;
+	if (i_is_value_false(s)) {
+		return 1;
+	} else if (i_is_value_true(s)) {
+		return 0;
+	} else {
+		fprintf(stderr, 
+		"%s: warning: extended option boolean value '%s' is improperly formatted, assuming false\n", swlib_utilname_get(), s);
+	}
+	return 1;
 }
 
 
 int
 swextopt_is_value_true(char * s)
 {
-	if (
-		s != NULL &&
-		(
-			strcasecmp(s, "true") == 0 ||
-			strcasecmp(s, "yes") == 0 ||
-			strcasecmp(s, "y") == 0 ||
-			0
-		)
-	) return 1;
+	if (i_is_value_true(s)) {
+		return 1;
+	} else if (i_is_value_false(s)) {
+		return 0;
+	} else {
+		fprintf(stderr, 
+		"%s: warning: extended option boolean value '%s' is improperly formatted, assuming false\n", swlib_utilname_get(), s);
+	}
 	return 0;
 }
 
@@ -435,16 +482,25 @@ getLongOptionNameFromValue(struct option * arr, int val)
 }
 
 int 
-getEnumFromName(char * optionname, struct extendedOptions * peop)
+getEnumFromName(char * fp_optionname, struct extendedOptions * peop)
 {
-	struct extendedOptions * eop;
-
-	eop = peop;
-	while (eop->optionNameM && strcmp(eop->optionNameM, optionname)) {
-		eop ++;
-	}
-	if (eop->optionNameM == NULL) return -1;
-	return (((char*)eop) - (char*)peop) / sizeof(struct extendedOptions);
+	int ret;
+	char * optionname;
+	STROB * tmp;
+	
+	tmp = strob_open(10);
+	strob_strcpy(tmp, fp_optionname);
+	optionname = strob_str(tmp);
+	
+	swlib_tr(optionname, (int)'_', (int)'-');
+	ret = i_getEnumFromName(optionname, peop);
+	if (ret >= 0) {
+		return ret;
+	}	
+	swlib_tr(optionname, (int)'-', (int)'_');
+	ret = i_getEnumFromName(optionname, peop);
+	strob_close(tmp);
+	return ret;
 }
 
 int 
