@@ -418,7 +418,6 @@ o__inline__
 void
 swheader_set_current_offset(SWHEADER * swheader, int n)
 {
-	/* swheader->current_offset_=n; */
 	swheader_set_current_offset_p_value(swheader, n);
 }
 
@@ -588,12 +587,8 @@ swheader_get_single_attribute_value(SWHEADER * swheader, char *keyword)
         return value;
 }
 
-/*
-* Deprecated 
-*/
 char *
-swheader_get_attribute(SWHEADER *swheader,
-					char *attribute_keyword) {
+swheader_get_attribute(SWHEADER *swheader, char *attribute_keyword) {
 	int multi;
 	char **list;
 	char **pp;
@@ -603,19 +598,13 @@ swheader_get_attribute(SWHEADER *swheader,
 	list = swheader_get_attribute_list(swheader,
 					attribute_keyword, &multi);
 	pp = list;
-
 	if (!list) return (char*)(NULL);
-
 	/* return the last item in the list. */	
-
 	while (*pp) {
-		/* if (ret) swbis_free(ret); */
 		ret=*pp;
 		pp++;
 	}
-
-	/* FIXME memory leak */
-	/* swbis_free(list); */
+	free(list);
 	return ret;
 }
 
@@ -626,10 +615,12 @@ swheader_get_attribute_list(SWHEADER *swheader,
 	struct swsdflt_defaults *swd;
 	char *line, *keyw, *headerline, **ret;
 	CPLOB * cplob_obj;
-	int object_offset=swheader_get_current_offset(swheader);
+	SWHEADER_STATE state;
 	
+	swheader_store_state(swheader, &state);
 	headerline=swheader_get_current_line(swheader);
 	if (swheaderline_get_type(headerline) != SWPARSE_MD_TYPE_OBJ) {
+		restore_state(swheader, &state);
 		return (char**)NULL;
 	}
 
@@ -668,7 +659,7 @@ swheader_get_attribute_list(SWHEADER *swheader,
 		}
 	}
 	ret = cplob_release(cplob_obj);
-	swheader_set_current_offset_p_value(swheader, object_offset);
+	restore_state(swheader, &state);
 	return ret;
 }
 
@@ -803,9 +794,12 @@ swheader_get_attribute_in_object(SWHEADER * swheader, char *keyword,
 {
 	int multi_line;
 	struct swsdflt_defaults *swd;
-	char * line, *prevline;
+	char * line;
+	char * prevline;
+	SWHEADER_STATE state;
 	
 	SWHEADER_E_DEBUG("");
+	swheader_store_state(swheader, &state);
 	if (object_keyword) {
 		swd=swsdflt_return_entry(object_keyword, keyword);
 		if (swd == NULL) {
@@ -830,6 +824,7 @@ swheader_get_attribute_in_object(SWHEADER * swheader, char *keyword,
 								keyword);
 			if (line) prevline = line;
 		}
+		restore_state(swheader, &state);
 		return prevline;
 	} else {
 		/*
@@ -838,6 +833,7 @@ swheader_get_attribute_in_object(SWHEADER * swheader, char *keyword,
 		if (is_multi_value) *is_multi_value = 1;
 		line = swheader_raw_get_attribute_in_object(swheader,
 								keyword);
+		restore_state(swheader, &state);
 		return line;
 	}
 }
@@ -866,11 +862,13 @@ swheader_fileobject2filehdr(SWHEADER * fileheader, struct new_cpio_header * file
 	char did_major = 0;
 	char did_minor = 0;
 	char did_type = 0;
+	SWHEADER_STATE state;
 
 	taru_init_header(file_hdr);
 	taru_init_header_digs(file_hdr);
 
-/*JL fprintf(stderr, ">> object start\n"); */
+	
+	swheader_store_state(fileheader, &state);
 
 	while((attr=swheader_get_next_attribute(fileheader))) {
 
@@ -878,44 +876,44 @@ swheader_fileobject2filehdr(SWHEADER * fileheader, struct new_cpio_header * file
 		value = swheaderline_get_value(attr, &len);
 		/*JL fprintf(stderr, "%s = [%s]\n", keyword, value); */
 
-		if (strcmp(keyword, "mode") == 0) {
+		if (strcmp(keyword, SW_A_mode) == 0) {
 			file_hdr->c_mode = 0;
 			taru_otoul(value, &(file_hdr->c_mode));
 			file_hdr->c_mode = file_hdr->c_mode & 07777;
 			(file_hdr->usage_maskM) |= TARU_UM_MODE;
-		} else if (strcmp(keyword, "size") == 0) {
+		} else if (strcmp(keyword, SW_A_size) == 0) {
 			file_hdr->c_filesize = (unsigned long)atol(value);		
 			if (file_hdr->digsM) {
 				swlib_strncpy(file_hdr->digsM->size, value, sizeof(file_hdr->digsM->size));
 				file_hdr->digsM->do_size = DIGS_ENABLE_ON;
 			}
 			did_size = 1;
-		} else if (strcmp(keyword, "path") == 0) {
+		} else if (strcmp(keyword, SW_A_path) == 0) {
 			ahsStaticSetTarFilename(file_hdr, value);
-		} else if (strcmp(keyword, "uid") == 0) {
+		} else if (strcmp(keyword, SW_A_uid) == 0) {
 			E_DEBUG("uid");
 			file_hdr->c_uid = (unsigned long)atol(value);		
 			(file_hdr->usage_maskM) |= TARU_UM_UID;
 			did_uid = 1;
-		} else if (strcmp(keyword, "gid") == 0) {
+		} else if (strcmp(keyword, SW_A_gid) == 0) {
 			E_DEBUG("gid");
 			file_hdr->c_gid = (unsigned long)atol(value);		
 			(file_hdr->usage_maskM) |= TARU_UM_GID;
 			did_gid = 1;
-		} else if (strcmp(keyword, "link_source") == 0) {
+		} else if (strcmp(keyword, SW_A_link_source) == 0) {
 			ahsStaticSetTarLinkname(file_hdr, value);
 			did_link_source = 1;
-		} else if (strcmp(keyword, "owner") == 0) {
+		} else if (strcmp(keyword, SW_A_owner) == 0) {
 			E_DEBUG("owner");
 			ahsStaticSetTarUsername(file_hdr, value);
 			did_uname = 1;
 			(file_hdr->usage_maskM) |= TARU_UM_OWNER;
-		} else if (strcmp(keyword, "group") == 0) {
+		} else if (strcmp(keyword, SW_A_group) == 0) {
 			E_DEBUG("group");
 			ahsStaticSetTarGroupname(file_hdr, value);
 			did_gname = 1;
 			(file_hdr->usage_maskM) |= TARU_UM_GROUP;
-		} else if (strcmp(keyword, "mtime") == 0) {
+		} else if (strcmp(keyword, SW_A_mtime) == 0) {
 			E_DEBUG("mtime");
 			file_hdr->c_mtime = strtoul(value, (char**)NULL, 10);
 			did_mtime = 1;
@@ -949,10 +947,10 @@ swheader_fileobject2filehdr(SWHEADER * fileheader, struct new_cpio_header * file
 				swlib_strncpy(file_hdr->digsM->sha512, value, sizeof(file_hdr->digsM->sha512));
 				file_hdr->digsM->do_sha512 = DIGS_ENABLE_ON;
 			}
-		} else if (strcmp(keyword, "type") == 0) {
+		} else if (strcmp(keyword, SW_A_type) == 0) {
 			info_filetype = (int)(*value);	
 			did_type = 1;
-		} else if (strcmp(keyword, "is_volatile") == 0) {
+		} else if (strcmp(keyword, SW_A_is_volatile) == 0) {
 			(file_hdr->usage_maskM) |= TARU_UM_IS_VOLATILE;
 		}
 	} /* while */
@@ -997,6 +995,7 @@ swheader_fileobject2filehdr(SWHEADER * fileheader, struct new_cpio_header * file
 		(!did_gname && !did_gid) ||
 		(!did_uname && !did_uid)
 	) {
+		swheader_restore_state(fileheader, &state);
 		return 1;
 	}
 
@@ -1017,7 +1016,7 @@ swheader_fileobject2filehdr(SWHEADER * fileheader, struct new_cpio_header * file
 	/*
 	 * FIXME, need to impose required attributes per spec.
 	 */
-
+	swheader_restore_state(fileheader, &state);
 	return 0;
 }
 
