@@ -254,7 +254,6 @@ task_wait_for(SWICOL * swicol, STROB * retbuf,
 				;	
 			}
 		} else {
-			/* fprintf(stderr, "JLXX [%s]\n", strob_str(buf)); */
 			/*
 			 * OK
 			 */
@@ -325,7 +324,6 @@ convert_result_to_event_list(char * event_string, STRAR * event_list)
 	char * current;
 	int ret;
 
-	/* fprintf(stderr, "JLX event string = [%s]\n", event_string);  */
 	E_DEBUG2("event string: %s", event_string);	
 
 	ret = strar_num_elements(event_list);
@@ -516,14 +514,6 @@ swicol_set_setvx(SWICOL * swicol, char * buf)
 	set_buf(&(swicol->setvxM), buf);
 }
 
-/*
-void
-swicol_set_blocksize(SWICOL * swicol, char * buf)
-{
-	set_buf(&(swicol->blocksizeM), buf);
-}
-*/
-
 void
 swicol_set_targetpath(SWICOL * swicol, char * buf)
 {
