@@ -392,7 +392,7 @@ swlib_i_digs_copy(int ofd, int ifd, intmax_t count, FILE_DIGS * digs, int adjunc
 			timebytes += wr;
 
 			E_DEBUG("");
-			if (io_req) {
+			if (io_req && io_req->tv_nsec) {
 				/*
 				* This is the bug delay
 				*/
@@ -640,7 +640,7 @@ swlib_i_pipe_pump(int suction_fd, int discharge_fd,
 			}
 			E_DEBUG("");
 			byteswritten += bytes;
-			if (io_req) {
+			if (io_req && io_req->tv_nsec) {
 				sleepbytes += bytes;
 				delay_sleep_pattern2(io_req, &sleepbytes, c_amount, byteswritten);
 			}
@@ -712,7 +712,7 @@ swlib_i_pipe_pump(int suction_fd, int discharge_fd,
 					}
 				}
 			}
-			if (io_req) {
+			if (io_req && io_req->tv_nsec) {
 				sleepbytes += bytes;
 				delay_sleep_pattern2(io_req, &sleepbytes, c_amount, byteswritten);
 			}
@@ -2144,8 +2144,8 @@ swlib_wait_on_all_pids(pid_t * pid, int num, int * status,
 	E_DEBUG("");
 	while (!done) {
 		done = 1;
-		usleep(100000);  /* Sleep 1/10th second, this greatly */
-				 /* improves performance on Cygwin    */
+		/* usleep(100000); */ /* Sleep 1/10th second, this greatly */
+				      /* improves performance on Cygwin    */
 		E_DEBUG("");
 		for(i=0; i<num; i++) {
 			if (pid[i] > 0) {
