@@ -86,11 +86,13 @@ static char * swsdflts_objects[] = {"host", "distribution", "product", "subprodu
 {sdf_distribution,sdf_POSIX_7_2_annex,	sdf_attr, 	"create_time",	 	16,		sdf_single_value,	sdf_PortableCharacterString, 	sdf_yes, 	""},
 {sdf_distribution,sdf_POSIX_7_2_annex,	sdf_attr, 	"number",	 	64,		sdf_single_value,	sdf_PortableCharacterString, 	sdf_yes, 	""},
 {sdf_distribution,sdf_POSIX_7_2_annex,	sdf_attr, 	"architecture",	 	64,		sdf_single_value,	sdf_PortableCharacterString, 	sdf_yes, 	""},
+{sdf_distribution,        sdf_swbis,	sdf_attr, 	"owner", 		sdf_undefined,	sdf_single_value,	sdf_PathnameCharacterString, 	sdf_yes, 	""},
+{sdf_distribution,        sdf_swbis,	sdf_attr, 	"group", 		sdf_undefined,	sdf_single_value,	sdf_PathnameCharacterString, 	sdf_yes, 	""},
 {sdf_distribution,        sdf_swbis,	sdf_attr, 	"control_directory", 	sdf_undefined,	sdf_single_value,	sdf_PathnameCharacterString, 	sdf_yes, 	""},
 {sdf_distribution,        sdf_swbis,	sdf_attr, 	"release",	 	sdf_undefined,	sdf_single_value,	sdf_PortableCharacterString, 	sdf_yes, 	""},
 {sdf_distribution,        sdf_swbis,	sdf_attr, 	"url",	 		sdf_undefined,	sdf_single_value,	sdf_PortableCharacterString, 	sdf_yes, 	""},
 {sdf_distribution,        sdf_swbis,	sdf_attr, 	"chksum_md5",	 	sdf_undefined,	sdf_single_value,	sdf_PortableCharacterString, 	sdf_yes, 	""},
-{sdf_distribution,        sdf_swbis,	sdf_attr, 	"signature",	 	sdf_undefined,	sdf_single_value,	sdf_PortableCharacterString, 	sdf_yes, 	""},
+{sdf_distribution,        sdf_swbis,	sdf_attr, 	"signature",	 	sdf_undefined,	sdf_list,	sdf_PortableCharacterString, 	sdf_yes, 	""},
 {sdf_distribution,	sdf_swbis,	sdf_attr,	"rpm_default_prefix",	sdf_undefined,	sdf_single_value,	sdf_PathnameCharacterString,	sdf_yes,	"/"},
 {sdf_distribution,	sdf_swbis,	sdf_attr,	"rpm_obsoletes",	sdf_undefined,	sdf_single_value,	sdf_PathnameCharacterString,	sdf_no,	NULL},
 {sdf_distribution,        sdf_swbis,	sdf_attr, 	"rpm_buildarchs", 	sdf_undefined,	sdf_list,		sdf_PortableCharacterString, 	sdf_yes, 	""},
@@ -383,53 +385,50 @@ char * swsdflt_return_entry_keyword (char * buf, int entry_index) {
    }
 }
 
-/*
-char * 
-swsdflt_get_object_keyword(struct swsdflt_defaults * swd) {
-	return swd->object_keyword;
-}
+/* 
+ * char * 
+ * swsdflt_get_object_keyword(struct swsdflt_defaults * swd) {
+ * 	return swd->object_keyword;
+ * }
 
-o__inline__
-int 
-swsdflt_get_sanction(struct swsdflt_defaults * swd) {
-	return swd->sanction;
-}
+ * o__inline__
+ * int 
+ * swsdflt_get_sanction(struct swsdflt_defaults * swd) {
+ * 	return swd->sanction;
+ * }
 
-o__inline__
-int 
-swsdflt_get_group(struct swsdflt_defaults * swd) {
-	return swd->group;
-}
+ * o__inline__
+ * int 
+ * swsdflt_get_group(struct swsdflt_defaults * swd) {
+ * 	return swd->group;
+ * }
 */
 
 o__inline__
 char * 
 swsdflt_get_keyword(struct swsdflt_defaults * swd) {
+	if (!swd) return -1;
 	return swd->keyword;
 }
 
 o__inline__
 int 
 swsdflt_get_value_type(struct swsdflt_defaults * swd) {
+	if (!swd) return -1;
 	return (int)(swd->value_type);
 }
 
-/*
-char * 
-swsdflt_get_permitted_value(struct swsdflt_defaults * swd){
-	return swd->permitted_valueM;
-}
-*/
-
 o__inline__
 int 
 swsdflt_get_has_default_value(struct swsdflt_defaults * swd){
+	if (!swd) return -1;
 	return swd->has_default_value;
 }
 
 o__inline__
 char * 
 swsdflt_get_default_value_by_ent(struct swsdflt_defaults * swd){
+	if (!swd) return -1;
 	return swd->value;
 }
 
