@@ -278,8 +278,10 @@ swssh_landing_command(char * shellname, int opt_no_getconf)
 			return SWSSH_DASH_SHELL_COMMAND;	
 		} else if (strcmp(shellname, "posix") == 0) {
 			return SWSSH_POSIX_SHELL_COMMAND;	
+		} else if (strcmp(shellname, "detect") == 0) {
+			return SWSSH_SYSTEM_SHELL_COMMAND;	
 		} else {
-			return SWSSH_POSIX_SHELL_COMMAND;	
+			return SWSSH_SYSTEM_SHELL_COMMAND;	
 		}
 	} else {
 		if (opt_no_getconf == 0)
@@ -311,6 +313,45 @@ swssh_protect_shell_metacharacters(STROB * command, int nhops, char * taints) {
 	return 0;
 }
 
+int
+swssh_determine_target_path(char * target, char ** path)
+{
+	/*
+	* parse the path name at the end of the target.
+	*/
+	char * ds;
+	char * p;
+	
+	if (*target == ':' || *target == '/' || *target == '.' || *target == '-' ) {
+		*path = target;
+		target = target + strlen(*path);
+	} else {
+		ds = target;
+		p = strrchr(ds, ':');
+		if (p) {
+			(*path) = ++p;
+		} else if (!p) {
+			if (ds && (*ds == '/' || *ds == '.' ||
+							*ds == '-')) {
+				*path = ds;
+			}
+		} else {
+			;
+		}
+		if (*path) {
+			*path = target + strlen(target);
+			if (strstr(*path, TARGET_DELIM)) {
+				fprintf(stderr,
+				"target path not at terminal host\n");
+				return  -1;
+			} else {
+				return  -1;
+			}
+		}
+	}
+	return 0;
+}
+
 int
 swssh_parse_target(SHCMD * cmd, 
 			SHCMD * kmd, 
@@ -371,6 +412,7 @@ swssh_parse_target(SHCMD * cmd,
 	}
 	remote_ssh_command = strdup(strob_str(tmp));
 
+	/* ret = swssh_determine_target_path(target, path); */
 	{
 		/*
 		* parse the path name at the end of the target.
