@@ -2,13 +2,13 @@
  */
 
 /*
-   Copyright (C) 1998,2004,2005,2006  James H. Lowe, Jr.
+   Copyright (C) 1998,2004,2005,2006,2007  James H. Lowe, Jr.
    All rights reserved.
   
    COPYING TERMS AND CONDITIONS
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
   
    This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
   
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  */
 
 #include "swuser_config.h"
@@ -34,6 +34,8 @@
 #include "misc-fnmatch.h"
 #include "swverid.h"
 
+static int sg_swverid_uuid;   /* provides a uuid number for alternation groups of swverid objects */
+
 static char * rel_op_array[] = {
 		SWVERID_RELOP_NEQ,
 		SWVERID_RELOP_LT ,
@@ -70,6 +72,23 @@ get_ver_id_char_from_this(struct VER_ID * this)
 	return *verid;
 }
 
+static
+int
+determine_rel_op_code(char * rel_op)
+{
+	char * s;
+	int index;
+
+	index = 0;
+	s = rel_op_array[index];
+	while(s) {	
+		if (strcmp(s, rel_op) == 0) return index;
+		index++;
+		s = rel_op_array[index];
+	}
+	return -1;
+}
+
 static
 int
 compare_relop(int rel, int req)
@@ -166,14 +185,14 @@ compare_relop(int rel, int req)
 
 static
 int
-swverid_i_rpmvercmp(CPLOB * target_list, CPLOB * candidate_list)
+swverid_i_rpmvercmp(char * target_list, char * candidate_list)
 {
 	int ret;
 	char * target;
 	char * candidate;
 	
-	target = cplob_val(target_list, 0);
-	candidate = cplob_val(candidate_list, 0);
+	target = target_list;
+	candidate = candidate_list;
 	/*
 	 * FIXME, match multiple version ids.
 	 */
@@ -184,19 +203,38 @@ swverid_i_rpmvercmp(CPLOB * target_list, CPLOB * candidate_list)
 	return ret;
 }
 
+char *
+swverid_i_print(SWVERID * swverid, STROB * buf)
+{
+	char * s;
+	int i = 0;
+	int vi;
+	char * ret;
+
+	STROB * version = strob_open(32);
+	struct  VER_ID  * next;
+
+	while ((s = cplob_val(swverid->taglistM, i++))) {
+		if (i > 1) strob_strcat(buf, ".");
+		strob_strcat(buf, s);
+	}
+	next = swverid->ver_id_listM;
+	swverid_print_ver_id(next, version);
+	if (strob_strlen(version) > 0) {
+		strob_strcat(buf, ",");
+		strob_strcat(buf, strob_str(version));
+	}
+	ret = strob_str(buf);
+	strob_close(version);
+	return ret;
+}
+
 static
 int
-swverid_i_fnmatch(CPLOB * candidate_list, CPLOB * target_list, int flags)
+swverid_i_fnmatch(char * candidate, char * target, int flags)
 {
 	int ret;
-	char * target;
-	char * candidate;
 
-	target = cplob_val(target_list, 0);
-	candidate = cplob_val(candidate_list, 0);
-	/*
-	 * FIXME, match multiple version ids.
-	 */
 	if (!target || !candidate) {
 		return 0; /* match */
 	}
@@ -204,169 +242,40 @@ swverid_i_fnmatch(CPLOB * candidate_list, CPLOB * target_list, int flags)
 	return ret;
 } 
 
-static
-int
-compare_version_id(struct VER_ID * id_target, struct VER_ID * id_candidate, int req)
+static 
+void
+delete_version_id(struct VER_ID * verid)
 {
-	int ret = -1;
-	int retval = -1;
-	int flags;
-	char verid_letter;
-
-	if (!id_target || !id_candidate) {
-		if(id_candidate)
-			id_candidate->rel_op_codeM = SWVERID_CMP_NOT_USED;
-		return 0;
-	}
-
-	verid_letter = get_ver_id_char_from_this(id_candidate);
-	if (verid_letter == SWVERID_VERID_REVISION) {
-		/*
-		 * Its a revision, compare as dotted string.
-		 */
-
-		ret = swverid_i_rpmvercmp(id_target->value_listM, id_candidate->value_listM);
-		/* return 1: a is newer than b */
-		/*        0: a and b are the same version */
-		/*       -1: b is newer than a */
-
-		if (ret == 1) {
-			id_candidate->rel_op_codeM = SWVERID_CMP_LT;	
-		} else if (ret == -1) {
-			id_candidate->rel_op_codeM = SWVERID_CMP_GT;	
-			retval = 1;
-		} else if (ret == 0) {
-			id_candidate->rel_op_codeM = SWVERID_CMP_EQ;	
-			retval = 0;
-		} else {
-			return -1;
-		}
-	} else {
-		/*
-		 * Its not a revision, compare as a shell pattern
-		 */
-		flags =  0;
-		
-		ret = swverid_i_fnmatch (/*pattern*/ id_candidate->value_listM, /*string*/ id_target->value_listM, flags);
-		if (ret == 0) {
-			id_candidate->rel_op_codeM = SWVERID_CMP_EQ;	
-			retval = 0;
-		} else {
-			id_candidate->rel_op_codeM = SWVERID_CMP_NEQ;	
-			retval = 1;
-		}
-	}
-	retval = compare_relop(id_candidate->rel_op_codeM, req);
-	return retval;
-}
-
-static
-int
-compare_taglist(SWVERID * target, SWVERID * candidate)
-{
-	/*
-	 * 'target' is a fully qualified (does not contain any
-	 * patterns) software spec.
-	 * 'candidtate' may contain patterns
-	 */
-
-	return -1;
-}
-
-static
-int
-compare_all_version_ids(SWVERID * target, SWVERID * candidate)
-{
-	int ret;
-	struct VER_ID * id_target; 
-	struct VER_ID * id_candidate; 
-
-	/*
-	 * target is a fully qualified software spec
-	 * candidtate is a possible match to the target
-	 */
-
-	if (is_fully_qualified(target) == 0) {
-		/*
-		 * User error
-		 */
-		return -1;
-	}
-
-	/*
-	 * Compare the revision
-	 */
-	id_target = swverid_get_verid(target, SWVERID_VERIDS_REVISION);
-	id_candidate = swverid_get_verid(candidate, SWVERID_VERIDS_REVISION);
-	compare_version_id(id_target, id_candidate, SWVERID_CMP_NOT_USED);
-
-	/*
-	 * Compare the architecture
-	 */
-	id_target = swverid_get_verid(target, SWVERID_VERIDS_ARCHITECTURE);
-	id_candidate = swverid_get_verid(candidate, SWVERID_VERIDS_ARCHITECTURE);
-	compare_version_id(id_target, id_candidate, SWVERID_CMP_NOT_USED);
-
-	/*
-	 * Compare the vendor_tag
-	 */
-	id_target = swverid_get_verid(target, SWVERID_VERIDS_VENDOR_TAG);
-	id_candidate = swverid_get_verid(candidate, SWVERID_VERIDS_VENDOR_TAG);
-	compare_version_id(id_target, id_candidate, SWVERID_CMP_NOT_USED);
-
-	/*
-	 * Compare the location
-	 */
-	id_target = swverid_get_verid(target, SWVERID_VERIDS_LOCATION);
-	id_candidate = swverid_get_verid(candidate, SWVERID_VERIDS_LOCATION);
-	compare_version_id(id_target, id_candidate, SWVERID_CMP_NOT_USED);
-
-	/*
-	 * Compare the qualifier
-	 */
-	id_target = swverid_get_verid(target, SWVERID_VERIDS_QUALIFIER);
-	id_candidate = swverid_get_verid(candidate, SWVERID_VERIDS_QUALIFIER);
-	compare_version_id(id_target, id_candidate, SWVERID_CMP_NOT_USED);
-
-
-	return 0;
-}
-
-static
-int
-determine_rel_op_code(char * rel_op)
-{
-	char * s;
-	int index;
-
-	index = 0;
-	s = rel_op_array[index];
-	while(s) {	
-		if (strcmp(s, rel_op) == 0) return index;
-		index++;
-		s = rel_op_array[index];
-	}
-	return -1;
+	/* if (verid->valueM) free(verid->valueM); */
+	free(verid);
 }
 
 static 
 struct VER_ID *
-open_version_id(char * verid)
+create_version_id(char * version_id_string)
 {
 	struct VER_ID *ver_id=(struct VER_ID*)malloc(sizeof(struct VER_ID));
 	STROB * tmp;
-	char *s = verid;
+	char *s = version_id_string;
 	char *olds;
 	int count;
 	int ret;
 
+	memset(ver_id->ver_idM, '\0', sizeof(ver_id->ver_idM));
+	memset(ver_id->idM, '\0', sizeof(ver_id->idM));
+	memset(ver_id->vqM, '\0', sizeof(ver_id->vqM));
+	memset(ver_id->rel_opM, '\0', sizeof(ver_id->rel_opM));
+	ver_id->rel_op_codeM = 0;
+	ver_id->valueM = NULL;
+	ver_id->nextM = NULL;
+
 	tmp = strob_open(10);
 	olds = s;
 	while (isalpha(*s)) s++;  /* Step over the 'r', 'a', etc */
 
 	if ((olds - s) == 0 || (s - olds) > 2) {
 		/*
-		 * Error
+		 * Error, enforce that a verid is one or two chars only
 		 */
 		swbis_free(ver_id);
 		strob_close(tmp);
@@ -375,9 +284,28 @@ open_version_id(char * verid)
 
 	/*
 	 * Store the version id
+	 * If two chars long, the first char is a qualifier
 	 */
+	if ((s - olds) == 1) {
+		strncpy(ver_id->idM, olds, 1);
+		if (strpbrk(ver_id->idM, SWVERID_VERIDS_POSIX SWVERID_VERIDS_SWBIS) == NULL) {
+			return NULL;
+		}
+	} else if ((s - olds) == 2) {
+		strncpy(ver_id->vqM, olds, 1);
+		if (strpbrk(ver_id->vqM, SWVERID_QUALIFIER) == NULL) {
+			return NULL;
+		}
+		strncpy(ver_id->idM, olds+1, 1);
+		if (strpbrk(ver_id->idM, SWVERID_VERIDS_POSIX SWVERID_VERIDS_SWBIS) == NULL) {
+			return NULL;
+		}
+	} else {
+		fprintf(stderr, "swverid fatal error\n");
+		exit(77);
+	}
+
 	strncpy(ver_id->ver_idM, olds, (int)(s - olds));
-	ver_id->ver_idM[(int)(s - olds)] = '\0';
 
 	/*
 	 * Now read the rel_op
@@ -431,43 +359,244 @@ open_version_id(char * verid)
 	/*
 	 * Enforce the POSIX requirement that only the revision can use rel_ops
 	 */
-	if (*(ver_id->ver_idM) == SWVERID_VERID_REVISION) {
+	if (*(ver_id->idM) == SWVERID_VERID_REVISION) {
 		/*
 		 * all rel_ops supported except '='
 		fprintf(stderr, "JL [%s] %d\n", ver_id->rel_opM, ver_id->rel_op_codeM);
 		 */
 		if (ver_id->rel_op_codeM == SWVERID_CMP_EQ2) {
-			fprintf(stderr, "%s: warning: use '==' for the revision specs\n",
+			fprintf(stderr, "%s: error: invalid use of '=' for revision specs\n",
 					swlib_utilname_get());
-			/* return NULL; */
+			return NULL;
 		}
 	} else {
 		/*
 		 * the rel_op must be '='
 		 */
-		if (ver_id->rel_op_codeM != SWVERID_CMP_EQ2)
+		if (ver_id->rel_op_codeM != SWVERID_CMP_EQ2) {
 			return NULL;
+		}
 	}
 
-	/*
-	 * Now store the values, which can be '|' separated.
-	 */
-	ver_id->value_listM = cplob_open(2);
-	olds = s;
+	ver_id->valueM = NULL;
 
-	s = strob_strtok(tmp, olds, "|");
-	while(s) {
-		s = strdup(s);
-		SWLIB_ASSERT(s != NULL);
-		cplob_add_nta(ver_id->value_listM, s);
-		s = strob_strtok(tmp, NULL, "|\n\r");
+	if (strlen(s)) {
+		if (strcmp(ver_id->idM, SWVERID_VERIDS_LOCATION) == 0) {
+			/* Alter the value for a the LOCATION id, imposing
+			   that it must be an absolute path */
+			swlib_squash_trailing_slash(s);
+			if (*s != '/') {
+				strob_strcpy(tmp, "/");
+				strob_strcat(tmp, s);
+				s = strdup(strob_str(tmp));
+			} else {
+				s = strdup(s);
+			}
+		} else {
+			s = strdup(s);
+		}
+	} else {
+		/* support something like  *,r==,v=tag  
+		   which becomes *,r==*,v=tag
+		   This covers a bug in rpmpsf.c */
+		
+		/* No, it is appropropriate to leave it "" */
+		s = strdup(""); /* 2006-12-20  s = strdup("*"); */
 	}
+	SWLIB_ASSERT(s != NULL);
+
+	ver_id->valueM = s;
+
+	strob_close(tmp);
 	return ver_id;
 }
 
 static 
+struct VER_ID *
+copy_construct_version_id(struct VER_ID * ver_id) {
+	STROB * buf;
+	struct VER_ID * new_ver_id;
+	char * verid;
+	char * val;
+
+	if (ver_id == NULL) return NULL;
+
+	buf = strob_open(12);
+	strob_strcpy(buf, ver_id->vqM);
+	strob_strcat(buf, ver_id->idM);
+	strob_strcat(buf, ver_id->rel_opM);
+	if ((val=ver_id->valueM) != NULL) {
+		strob_strcat(buf, val);
+	} else {
+		;
+	}
+	
+	verid = strob_str(buf);
+	new_ver_id = create_version_id(verid);
+	strob_close(buf);
+	return new_ver_id;
+}
+	
+static
+void
+ver_ids_copy(SWVERID * dst, SWVERID * src)
+{
+	struct VER_ID * vid;
+	struct VER_ID * ver_id;
+	struct VER_ID * last;
+	struct VER_ID * copy_of_last;
+
+	/* Delete the old verids in dst */
+	ver_id = dst->ver_id_listM;
+	while(ver_id){
+		vid=ver_id->nextM;
+		swbis_free(ver_id);
+		ver_id=vid;
+	}
+	dst->ver_id_listM = NULL;
+
+	/* Create and add new ver_ids */
+	last = src->ver_id_listM;
+	/*
+	copy_of_last = copy_construct_version_id(last);
+	dst->ver_id_listM = NULL;
+	swverid_add_verid(dst, copy_of_last);
+	*/
+	while (last) {
+		copy_of_last = copy_construct_version_id(last);
+		swverid_add_verid(dst, copy_of_last);
+		last = last->nextM;
+	}
+}
+
+static
 int
-parse_version_id_string(SWVERID * swverid, char * verid_string)
+compare_version_id(struct VER_ID * id_target, struct VER_ID * id_candidate, int req)
+{
+	int ret = -1;
+	int retval = -1;
+	int flags;
+	char verid_letter;
+
+	if (!id_target || !id_candidate) {
+		if(id_candidate)
+			id_candidate->rel_op_codeM = SWVERID_CMP_NOT_USED;
+		return 0;
+	}
+
+	verid_letter = get_ver_id_char_from_this(id_candidate);
+	if (verid_letter == SWVERID_VERID_REVISION) {
+		/*
+		 * Its a revision, compare as dotted string.
+		 */
+
+		ret = swverid_i_rpmvercmp(id_target->valueM, id_candidate->valueM);
+		/* return 1: a is newer than b */
+		/*        0: a and b are the same version */
+		/*       -1: b is newer than a */
+
+		if (ret == 1) {
+			id_candidate->rel_op_codeM = SWVERID_CMP_LT;	
+		} else if (ret == -1) {
+			id_candidate->rel_op_codeM = SWVERID_CMP_GT;	
+			retval = 1;
+		} else if (ret == 0) {
+			id_candidate->rel_op_codeM = SWVERID_CMP_EQ;	
+			retval = 0;
+		} else {
+			return -1;
+		}
+	} else {
+		/*
+		 * Its not a revision, compare as a shell pattern
+		 */
+		flags =  0;
+		
+		ret = swverid_i_fnmatch (/*pattern*/ id_candidate->valueM, /*string*/ id_target->valueM, flags);
+		if (ret == 0) {
+			id_candidate->rel_op_codeM = SWVERID_CMP_EQ;	
+			retval = 0;
+		} else {
+			id_candidate->rel_op_codeM = SWVERID_CMP_NEQ;	
+			retval = 1;
+		}
+	}
+	retval = compare_relop(id_candidate->rel_op_codeM, req);
+	return retval;
+}
+
+static
+int
+compare_taglist(SWVERID * pattern, SWVERID * fq_candidate)
+{
+
+
+
+
+	return -1;
+}
+
+static
+int
+compare_all_version_ids(SWVERID * target, SWVERID * candidate)
+{
+	struct VER_ID * id_target; 
+	struct VER_ID * id_candidate; 
+
+	/*
+	 * target is a fully qualified software spec
+	 * candidtate is a possible match to the target
+	 */
+
+	if (is_fully_qualified(target) == 0) {
+		/*
+		 * User error
+		 */
+		return -1;
+	}
+
+	/*
+	 * Compare the revision
+	 */
+	id_target = swverid_get_verid(target, SWVERID_VERIDS_REVISION, 1);
+	id_candidate = swverid_get_verid(candidate, SWVERID_VERIDS_REVISION, 1);
+	compare_version_id(id_target, id_candidate, SWVERID_CMP_NOT_USED);
+
+	/*
+	 * Compare the architecture
+	 */
+	id_target = swverid_get_verid(target, SWVERID_VERIDS_ARCHITECTURE, 1);
+	id_candidate = swverid_get_verid(candidate, SWVERID_VERIDS_ARCHITECTURE, 1);
+	compare_version_id(id_target, id_candidate, SWVERID_CMP_NOT_USED);
+
+	/*
+	 * Compare the vendor_tag
+	 */
+	id_target = swverid_get_verid(target, SWVERID_VERIDS_VENDOR_TAG, 1);
+	id_candidate = swverid_get_verid(candidate, SWVERID_VERIDS_VENDOR_TAG, 1);
+	compare_version_id(id_target, id_candidate, SWVERID_CMP_NOT_USED);
+
+	/*
+	 * Compare the location
+	 */
+	id_target = swverid_get_verid(target, SWVERID_VERIDS_LOCATION, 1);
+	id_candidate = swverid_get_verid(candidate, SWVERID_VERIDS_LOCATION, 1);
+	compare_version_id(id_target, id_candidate, SWVERID_CMP_NOT_USED);
+
+	/*
+	 * Compare the qualifier
+	 */
+	id_target = swverid_get_verid(target, SWVERID_VERIDS_QUALIFIER, 1);
+	id_candidate = swverid_get_verid(candidate, SWVERID_VERIDS_QUALIFIER, 1);
+	compare_version_id(id_target, id_candidate, SWVERID_CMP_NOT_USED);
+
+
+	return 0;
+}
+
+static 
+int
+parse_version_ids_string(SWVERID * swverid, char * verid_string)
 {
 	struct VER_ID *verid;
 	STROB * buf = strob_open(10);
@@ -475,7 +604,7 @@ parse_version_id_string(SWVERID * swverid, char * verid_string)
 
 	s = strob_strtok(buf, verid_string, ",");
 	while (s) {
-		verid = open_version_id(s);	
+		verid = create_version_id(s);	
 		if (verid == (struct VER_ID *)(NULL)) return -1;
 		swverid_add_verid(swverid, verid);
 		s = strob_strtok(buf, NULL, ",");
@@ -513,13 +642,28 @@ parse_swspec_string (SWVERID * swverid)
 	 */
 	tags = strob_strtok(tmp, source, ",");
 	tag = strob_strtok(tag_tmp2, tags, ".");
+
+	if (strpbrk(tag, SWVERID_RELOP_NEQ SWVERID_RELOP_LT
+			SWVERID_RELOP_LTE SWVERID_RELOP_EQ2
+			SWVERID_RELOP_EQ SWVERID_RELOP_GTE
+				SWVERID_RELOP_GT)) {
+		/* it looks like a verid, with no tags given,
+		   that is tag cannot have =><! chars,
+		   set 'tag' to a "*" */
+		strob_strcpy(tag_tmp2, "*");
+		strob_strcat(tag_tmp2, ",");
+		strob_strcat(tag_tmp2, source);
+		tags = strob_strtok(tmp, strob_str(tag_tmp2), ",");
+		tag = strob_strtok(tag_tmp2, tags, ".");
+	}
+
 	while (tag) {
 		cplob_add_nta(swverid->taglistM, strdup(tag));
 		tag = strob_strtok(tag_tmp2, NULL, ".");
 	}
 
 	/*
-	 * parse the version ids which are colon
+	 * parse the version ids which are comma
 	 * separated strings.
 	 */
 
@@ -528,7 +672,12 @@ parse_swspec_string (SWVERID * swverid)
 	if (verids) {
 		verid = verids;
 		while (verid) {
-			ret = parse_version_id_string(swverid, verid);
+			if (strcmp(verid, "*") == 0) {
+				/* special case to handle ``foo,*'' */
+				ret = 0;
+			} else {
+				ret = parse_version_ids_string(swverid, verid);
+			}
 			if (ret) {
 				fprintf(stderr, "%s: error parsing version id [%s]\n",
 					swlib_utilname_get(),  verid);
@@ -565,13 +714,138 @@ classify_namespace (char * object_kw)
 	}
 }
 
+void
+i_replace_verid(SWVERID * swverid, struct VER_ID  * verid, int do_replace) {
+	char new_id;
+	struct  VER_ID  * prev;
+	struct  VER_ID  * last;
+	struct  VER_ID  * newverid;
+
+	last = swverid->ver_id_listM;
+	verid->nextM = NULL;
+	prev = NULL;
+ 	new_id = get_ver_id_char_from_this(verid);
+	if (!last) {
+		newverid = copy_construct_version_id(verid);
+		swverid_add_verid(swverid, newverid);
+		return;
+	}	
+	while (last) {
+		if (
+			get_ver_id_char_from_this(last) == new_id &&
+			do_replace
+		) {
+			newverid = copy_construct_version_id(verid);
+			if (prev) {
+				prev->nextM = newverid;
+			}
+			newverid->nextM = last->nextM;
+			return;
+		} else if (
+			get_ver_id_char_from_this(last) == new_id &&
+			do_replace == 0
+		) {
+			return;
+		}
+		prev = last;
+		last = last->nextM;
+	}
+	newverid = copy_construct_version_id(verid);
+	swverid_add_verid(swverid, newverid);
+}
+
 /* ------------------- Public Functions ---------------------------------*/
 
 SWVERID *
-swverid_open(char * object_keyword, char *swversion_string)
+swverid_copy(SWVERID * src)
+{
+	SWVERID * dst;
+	char * tag;
+	int n;
+
+	dst = swverid_open(NULL, NULL);
+
+	if (src->object_nameM)
+		dst->object_nameM = strdup(src->object_nameM);
+	else
+		dst->object_nameM = NULL;
+
+	if (src->source_copyM)
+		dst->source_copyM = strdup(src->source_copyM);
+	else
+		dst->source_copyM = NULL;
+
+	if (src->catalogM) 
+		dst->catalogM = strdup(src->catalogM);
+	else
+		dst->catalogM = NULL;
+
+	dst->use_path_compareM = src->use_path_compareM;
+	dst->namespaceM = src->namespaceM;
+	dst->comparison_codeM = src->comparison_codeM;
+
+	cplob_close(dst->taglistM);
+	dst->taglistM = cplob_open(1);
+	cplob_add_nta(dst->taglistM, (char*)(NULL));
+
+	n = 0;
+	while((tag=swverid_get_tag(src, n++)) != NULL) {
+		cplob_add_nta(dst->taglistM, strdup(tag));
+	}
+
+	ver_ids_copy(dst, src);
+	return dst;
+}
+
+void
+swverid_add_tag(SWVERID * swverid, char * tag)
+{
+	cplob_add_nta(swverid->taglistM, strdup(tag));
+}
+
+void
+swverid_ver_id_set_object_qualifier(SWVERID * swverid, char * objkeyword)
+{
+	struct  VER_ID  *last;
+	last = swverid->ver_id_listM;
+	while (last) {
+		last->vqM[0] = *objkeyword;
+		last->vqM[1] = '\0';
+		last = last->nextM;
+	}
+}
+
+int
+swverid_ver_id_unlink(SWVERID * swverid, struct VER_ID * verid)
+{
+	struct  VER_ID  *prev;
+	struct  VER_ID  *last;
+	prev = NULL;
+	last = swverid->ver_id_listM;
+	while (last) {
+		if (last == verid) {
+			if (prev) {
+				prev->nextM = last->nextM;
+			} else {
+				swverid->ver_id_listM = swverid->ver_id_listM->nextM;
+			}
+			delete_version_id(verid);
+			return 0;
+		}
+		prev = last;
+		last = last->nextM;
+	}
+	return -1;
+}
+
+static
+SWVERID *
+swverid_i_open(char * object_keyword, char *swversion_string)
 {
 	int ret;
-	SWVERID *swverid=(SWVERID*)malloc(sizeof(SWVERID));
+	SWVERID * swverid;
+
+	swverid = (SWVERID*)malloc(sizeof(SWVERID));
 	if (!swverid) return NULL;
 	
 	swverid->object_nameM=swlib_strdup("");
@@ -585,7 +859,9 @@ swverid_open(char * object_keyword, char *swversion_string)
 	swverid->source_copyM = (char*)(NULL);
 	swverid->use_path_compareM = 0;
 	swverid->swutsM = swuts_create();
-
+	swverid->altM = NULL;
+	swverid->alter_uuidM = 0; /* unset */
+	/* swverid->dependency_statusM = SWVERID_DEPSTATUS_UNSET; */
 	if (swversion_string != (char*)(NULL)) {
 		swverid->source_copyM = swlib_strdup(swversion_string);
 		ret = parse_swspec_string(swverid);
@@ -596,6 +872,49 @@ swverid_open(char * object_keyword, char *swversion_string)
 	return swverid;
 }
 
+SWVERID *
+swverid_open(char * object_keyword, char *swversion_string)
+{
+	SWVERID * swverid;
+	SWVERID * parent;
+	SWVERID * last;
+	STROB * tmp;
+	int i;
+	char * s;
+
+	if (swversion_string != (char*)(NULL)) {
+		i = 0;
+		last = NULL;
+		parent = NULL;
+		tmp = strob_open(32);
+		s = strob_strtok(tmp, swversion_string, "|\n\r");
+		while(s) {	
+			swverid = swverid_i_open(object_keyword, s);
+			if (swverid == NULL) return NULL;
+			if (last)
+				last->altM = swverid;	
+			last = swverid;
+			if (i == 0)
+				parent = swverid;
+			s = strob_strtok(tmp, NULL, "|\n\r");
+			i++;
+		}
+		if (parent == NULL) return NULL;
+		last = parent;
+		if (sg_swverid_uuid == 0)
+			sg_swverid_uuid++;
+		parent->alter_uuidM = sg_swverid_uuid++;
+		while((last=swverid_get_alternate(last))) {
+			last->alter_uuidM = parent->alter_uuidM;
+		}
+		strob_close(tmp);
+	} else {
+		parent = swverid_i_open(object_keyword, NULL);
+		if (parent) parent->alter_uuidM = sg_swverid_uuid++;
+	}
+	return parent;
+}
+
 void
 swverid_set_namespace(SWVERID * swverid, char * object_keyword)
 {
@@ -620,6 +939,8 @@ swverid_close(SWVERID * swverid)
 		swbis_free(swverid->source_copyM);
 		swverid->source_copyM = NULL;
 	}
+	/* if (swverid->altM) swverid_close(swverid->altM); */
+
 	/* FIXME this causes a core dump: cplob_close(swverid->taglistM); */
 	swuts_delete(swverid->swutsM);
 	swbis_free(swverid);
@@ -836,7 +1157,7 @@ swverid_add_attribute(SWVERID * swverid, char * object_keyword, char * keyword,
 	/*
 	 * Now parse the constructed version id
 	 */
-	version_id = open_version_id(strob_str(verid_string));
+	version_id = create_version_id(strob_str(verid_string));
 	if (version_id == NULL) {
 		return -1;
 	}
@@ -924,43 +1245,98 @@ swverid_get_ver_id_char(char * object, char * attr_name)
 }
 
 struct VER_ID *
-swverid_get_verid(SWVERID * swverid, char * fp_verid) {
+swverid_get_verid(SWVERID * swverid, char * fp_verid, int occno) {
 	char * verid;
+	char * qualifier;
+	int occ_count;
 	struct  VER_ID  *prev;
 	struct  VER_ID  *last;
 
 	verid = fp_verid;
-
+	occ_count = 0;
 	/*
 	 * Step over the object modifier letter
 	 * e.g. 'br' 'pr' etc which is an suggested
 	 * extension 
 	 */
+	if (strlen(verid) > 2) {
+		fprintf(stderr, "invalid version id: %s\n", fp_verid);
+		return NULL;
+	}
+
 	if (strlen(verid) > 1)
 		verid++;
-
+	
+	if (strlen(verid) > 1)
+		qualifier = verid;
+	else
+		qualifier = "";
+ 
 	last = swverid->ver_id_listM;
 	while (last) {
-		if (
-			*(last->ver_idM) == *verid ||
-			*(last->ver_idM + 1) == *verid ||
-			1
-		) {
-			/*
-			 * Found it
-			 */
-			return last;
+		if ( *(last->idM) == *verid) {
+			if (strlen(qualifier) > 0) {
+				if (strlen(last->vqM) > 0) {
+					if (*(last->vqM) == *qualifier) {
+						if (occ_count >= occno - 1) {
+							return last;
+						}
+						occ_count++;
+					}
+				} else {
+					/* FIXME, what if *(last->vqM) exists? */
+					if (occ_count >= occno - 1) {
+						return last;
+					}
+					occ_count++;
+				}
+			} else {
+				/*
+				 * Found it
+				 */
+				if (occ_count >= occno - 1) {
+					return last;
+				}
+				occ_count++;
+			}
 		}
 		last = last->nextM;
 	}
 	return NULL;
 }
 
+char *
+swverid_print_ver_id(struct VER_ID * next, STROB * buf)
+{
+	int vi;
+	char * val;
+	int n = 0;
+
+	strob_strcpy(buf, "");
+	while (next) {
+		if (n++) strob_strcat(buf, ",");
+		strob_strcat(buf, next->vqM);
+		strob_strcat(buf, next->idM);
+		strob_strcat(buf, next->rel_opM);
+		vi = 0;
+		if ((val=next->valueM) != NULL) {
+			strob_strcat(buf, val);
+		} else {
+			;
+		}
+		next = next->nextM; 
+	}
+	return strob_str(buf);
+}
+
 void
 swverid_add_verid(SWVERID * swverid, struct VER_ID  * verid) {
-	struct  VER_ID  *prev;
-	struct  VER_ID  *last = swverid->ver_id_listM;
-	verid->nextM = NULL;
+	struct  VER_ID  * prev;
+	struct  VER_ID  * last;
+
+	last = swverid->ver_id_listM;
+	if (verid)
+		verid->nextM = NULL;
 
 	if (!last) {
 		swverid->ver_id_listM = verid;
@@ -974,50 +1350,114 @@ swverid_add_verid(SWVERID * swverid, struct VER_ID  * verid) {
 	prev->nextM = verid;
 }
 
+void
+swverid_add_verid_if(SWVERID * swverid, struct VER_ID  * verid)
+{
+	/* add if not already present */
+	i_replace_verid(swverid, verid, 0 /* do_replace */);
+}
+
+void
+swverid_replace_verid(SWVERID * swverid, struct VER_ID  * verid) {
+	/* add or replace */
+	i_replace_verid(swverid, verid, 1 /* do_replace */);
+}
+
+SWVERID *
+swverid_get_alternate(SWVERID * swverid) {
+	return swverid->altM;
+}
+
+void
+swverid_disconnect_alternates(SWVERID * swverid) {
+	SWVERID * oldparent;
+	SWVERID * parent;
+	parent = swverid;
+	while (parent) {
+		oldparent = parent;
+		parent = parent->altM;
+		oldparent->altM = NULL;	
+	}
+}
+
+char *
+swverid_debug_print(SWVERID * swverid, STROB * buf)
+{
+	STROB  * tmp;
+
+	tmp = strob_open(32);
+	swverid_print(swverid, tmp);
+	strob_strcpy(buf, "");
+	strob_sprintf(buf, 0, "%d: %s", swverid->alter_uuidM, strob_str(tmp));
+	strob_close(tmp);
+	return strob_str(buf);
+}
+
 char *
 swverid_print(SWVERID * swverid, STROB * buf)
 {
-	char * s;
-	int i = 0;
-	int vi = 0;
 	char * ret;
-	char * val;
-	STROB * version = strob_open(32);
-	struct  VER_ID  * next;
+	SWVERID * next;
 
-	strob_strcpy(version, "");
-	while ((s = cplob_val(swverid->taglistM, i++))) {
-		if (i > 1) strob_strcat(version, ".");
-		strob_strcat(version, s);
+	strob_strcpy(buf, "");
+	swverid_i_print(swverid, buf);
+	next = swverid;	
+	while((next=swverid_get_alternate(next))) {
+		strob_strcat(buf, "|");
+		swverid_i_print(next, buf);
 	}
-
-	next = swverid->ver_id_listM;
-	while (next) {
-		strob_strcat(version, ",");
-		strob_strcat(version, next->ver_idM);
-		strob_strcat(version, next->rel_opM);
-		while((val=cplob_val(next->value_listM, vi++))) {
-			if (vi>1)
-				strob_strcat(version, "|");
-			strob_strcat(version, val);
-		}
-		next = next->nextM; 
-	}
-
-	strob_strcpy(buf, strob_str(version));
 	ret = strob_str(buf);
-	strob_close(version);
 	return ret;
 }
 
 char *
-swverid_show_object_debug(SWVERID * swverid, STROB * buf)
+swverid_show_object_debug(SWVERID * swverid, STROB * buf, char * prefix)
 {
+	SWVERID * xx;
+	STROB * buf1;
+	char * tag;
+	int in;
+
+	xx = swverid;
+	buf1 = strob_open(10);
+
 	strob_strcpy(buf, "");
-	if (! swverid_print(swverid, buf))
-		return "";
-	strob_strcat(buf, "\n");
-	strob_sprintf(buf, 1,
+	swverid_print(swverid, buf1);
+
+/*	
+	char * object_nameM;
+	char * source_copyM;
+	char * catalogM;
+	int use_path_compareM;
+	CPLOB * taglistM;
+	int namespaceM;	
+	Swverid_Cmp_Code comparison_codeM;
+	struct VER_ID * ver_id_listM;	
+	SWUTS * swutsM;		
+*/
+
+	strob_sprintf(buf, 1, "%s%p (SWVERID*)\n", prefix,  (void*)xx);
+	strob_sprintf(buf, 1, "%s%p swverid_print() = [%s]\n", prefix, (void*)xx, swverid_print(swverid, buf1));
+	strob_sprintf(buf, 1, "%s%p->object_nameM = [%s]\n", prefix, (void*)xx,  xx->object_nameM);
+	strob_sprintf(buf, 1, "%s%p->source_copyM = [%s]\n", prefix, (void*)xx,  xx->source_copyM);
+	strob_sprintf(buf, 1, "%s%p->catalogM = [%s]\n", prefix, (void*)xx,  xx->catalogM);
+	strob_sprintf(buf, 1, "%s%p->use_path_compareM = [%d]\n", prefix, (void*)xx,  xx->use_path_compareM);
+	strob_sprintf(buf, 1, "%s%p->comparison_codeM = [%d]\n", prefix, (void*)xx,  xx->comparison_codeM);
+	strob_sprintf(buf, 1, "%s%p->ver_id_listM = (struct VER_ID*)%p\n", prefix, (void*)xx,  (void*)(xx->ver_id_listM));
+	strob_sprintf(buf, 1, "%s%p->ver_id_listM = [%s]\n", prefix, (void*)xx,  swverid_print_ver_id(xx->ver_id_listM, buf1));
+
+	in = 0;
+	strob_strcpy(buf1, "");
+	while((tag=cplob_val(swverid->taglistM, in++)) != NULL) {
+		if (in>1)
+			strob_sprintf(buf1, 1, ".", tag);
+		strob_sprintf(buf1, 1, "%s", tag);
+	}
+	strob_sprintf(buf, 1, "%s%p->taglistM = (CPLOB*)(%p)\n", prefix, (void*)xx,  (void*)(xx->taglistM));
+	strob_sprintf(buf, 1, "%s%p->taglistM = [%s]\n", prefix, (void*)xx,  strob_str(buf1));
+	strob_sprintf(buf, 1, "%s%p->namespaceM = [%d]\n", prefix, (void*)xx, xx->namespaceM);
+
+	strob_sprintf(buf, STROB_DO_APPEND,
 			"os_name=%s\n"
 			"os_version=%s\n"
 			"os_release=%s\n"
@@ -1049,3 +1489,42 @@ swverid_u_parse_swspec(SWVERID * swverid, char * swspec)
 	swverid->source_copyM = savesource;
 	return list;
 }
+
+struct VER_ID *
+swverid_create_version_id(char * verid_string) {
+	struct VER_ID * ver_id;
+	ver_id = create_version_id(verid_string);
+	return ver_id;
+}
+
+char *
+swverid_get_verid_value(SWVERID * swverid, char * fp_verid, int occno) {
+	char * ret;
+	struct VER_ID * verid; 
+	verid = swverid_get_verid(swverid, fp_verid, occno);
+	if (!verid) return (char*)NULL; /* ""; */
+	ret = verid->valueM;
+	return ret;
+}
+
+int
+swverid_delete_non_fully_qualified_verids(SWVERID * swverid)
+{
+	int retval;
+	struct  VER_ID  *tmp;
+	struct  VER_ID  *last;
+
+	retval = 0;
+	last = swverid->ver_id_listM;
+	while (last) {
+		if (swlib_is_sh_tainted_string(last->valueM)) {
+			tmp = last;
+			last = last->nextM;
+			swverid_ver_id_unlink(swverid, tmp);
+			retval++;
+		} else {
+			last = last->nextM;
+		}
+	}
+	return retval;
+}
