@@ -286,8 +286,8 @@ plain_source_tarball_write_psf_buf(TOPSF * topsf, STROB * psf)
 	*/
 
 	strob_sprintf(psf, STROB_NO_APPEND, "");
-	strob_sprintf(psf, STROB_DO_APPEND, "distribution\n");
-	strob_sprintf(psf, STROB_DO_APPEND, "layout_version 1.0\n");
+	strob_sprintf(psf, STROB_DO_APPEND, SW_A_distribution "\n");
+	strob_sprintf(psf, STROB_DO_APPEND, SW_A_layout_version " 1.0\n");
 	strob_sprintf(psf, STROB_DO_APPEND, "dfiles dfiles\n");
 	strob_sprintf(psf, STROB_DO_APPEND, "pfiles pfiles\n");
 	strob_sprintf(psf, STROB_DO_APPEND, SW_A_control_directory " %s\n", topsf->format_desc_->pathname_prefixM);
@@ -433,10 +433,14 @@ slack_write_psf_buf(TOPSF * topsf, STROB * psf)
 	*/	
 
 	strob_sprintf(psf, STROB_NO_APPEND, "");
-	strob_sprintf(psf, STROB_DO_APPEND, "distribution\n");
-	strob_sprintf(psf, STROB_DO_APPEND, "layout_version 1.0\n");
+	strob_sprintf(psf, STROB_DO_APPEND, SW_A_distribution "\n");
+	strob_sprintf(psf, STROB_DO_APPEND, SW_A_layout_version " 1.0\n");
 	strob_sprintf(psf, STROB_DO_APPEND, "dfiles dfiles\n");
 	strob_sprintf(psf, STROB_DO_APPEND, "pfiles pfiles\n");
+	if (topsf->ownerM)
+		strob_sprintf(psf, STROB_DO_APPEND, SW_A_owner " %s\n", topsf->ownerM);
+	if (topsf->groupM)
+		strob_sprintf(psf, STROB_DO_APPEND, SW_A_group " %s\n", topsf->groupM);
 
 	strob_sprintf(psf, STROB_DO_APPEND, "\n");
 	strob_sprintf(psf, STROB_DO_APPEND, "vendor\n");
@@ -687,6 +691,8 @@ TOPSF * topsf_open(char * package_name, int oflags)
 	else
 		topsf->pkgfilenameM = strdup(package_name);
 	topsf->checkdigestnameM = NULL;
+	topsf->ownerM = NULL;
+	topsf->groupM = NULL;
 	return topsf_i_package_open(topsf, oflags);
 }
 
