@@ -64,6 +64,8 @@ typedef struct {
 	void * rpmpsfM; /* does not exist */
 	char * pkgfilenameM;
 	char * checkdigestnameM;
+	char * ownerM;
+	char * groupM;
 } TOPSF;
 
 TOPSF * topsf_open(char * package_name, int oflags);
