@@ -94,6 +94,8 @@ void  usage (char * progname, FILE * fp) {
     fprintf (fp, "    --deb-control   write uncompressed control.tar.gz tar file to stdout.\n");
     fprintf (fp, "    --deb-data   write uncompressed data.tar.gz tar file to stdout.\n");
     fprintf (fp, "    --create-time=cal_time  Use this time for archive header times\n");
+    fprintf (fp, "    --owner=NAME  package owner\n");
+    fprintf (fp, "    --group=NAME  package group\n");
     fprintf (fp, "    -d, --debug-level=TYPE    always use 'link'\n");
     fprintf (fp, "    -D checkdigest  checkdigest script, applies to plain tarball translation.\n");
     fprintf (fp, "    -x, --use-recursive-fileset Use \"file *\" instead of individual file definitions.\n");
@@ -472,6 +474,8 @@ main(int argc, char **argv)
 	int info_only = 0;
 	int psf_only = 0;
 	int tarpipe[2];
+	char * owner;
+	char * group;
 	char  *progname;
 	char  *checkdigestname = NULL;
 	char * wopt_create_time = (char*)NULL;
@@ -494,6 +498,8 @@ main(int argc, char **argv)
 	yylval.strb = strob_open (8);
 	strcpy(swlex_filename,"none");
 	*format='\0';
+	owner = NULL;
+	group = NULL;
 
 	swlib_utilname_set("lxpsf");
 
@@ -522,6 +528,8 @@ main(int argc, char **argv)
                {"create-time", 1, 0, 199},
                {"deb-control", 0, 0, 200},
                {"deb-data", 0, 0, 201},
+               {"owner", 1, 0, 202},
+               {"group", 1, 0, 203},
                {0, 0, 0, 0}
              };
 
@@ -648,6 +656,12 @@ main(int argc, char **argv)
 				exit(0);
 		}
 	         break;
+               case 202:
+			owner=strdup(optarg);
+	         	break;
+               case 203:
+			group=strdup(optarg);
+	         	break;
                default:
                  usage(progname, stderr);
 		 exit(1);
@@ -668,6 +682,11 @@ main(int argc, char **argv)
 		exit(1);
 	}
 
+	if (owner)
+		topsf->ownerM = strdup(owner);
+	if (group)
+		topsf->groupM = strdup(group);
+
 	if (wopt_create_time) {
 		topsf_set_mtime(topsf, (time_t)(create_time));
 	}
