@@ -173,7 +173,6 @@ swi_xfile_add_control_script(SWI * swi, SWI_XFILE * xfile, char * name,
 	SWI_FILE_MEMBER * s;
 
 	sc = swi_control_script_create();
-	/* offset = swi->xformatM->swvarfsM->current_header_offsetM;*/
 	s = swi_xfile_construct_file_member(xfile, name, fd,
 					swi->xformatM->swvarfsM);
 	sc->baseM.tagM = strdup(tag);
@@ -187,7 +186,6 @@ void
 swi_xfile_add_file_member(SWI * swi, SWI_XFILE * xfile, char * name, int fd)
 {
 	SWI_FILE_MEMBER * s;
-	/* offset = swi->xformatM->swvarfsM->current_header_offsetM; */
 	s = swi_xfile_construct_file_member(xfile, name, fd,
 					swi->xformatM->swvarfsM);
 	cplob_add_nta(xfile->archive_filesM, (char*)s);
@@ -218,36 +216,6 @@ swi_get_distribution_attributes(SWI * swi, SWHEADER * swheader)
 		swi->swi_pkgM->pfiles_attributeM = strdup(SW_A_pfiles);
 
 	return 0;
-
-
-	/*
-	char * obj;
-	char * line;
-	char * value;
-	
-	swi_com_header_manifold_reset(swheader);
-	obj = swheader_get_object_by_tag(swheader, SW_A_distribution, "*" );
-	line = swheader_get_attribute(swheader, SW_A_dfiles);
-	if (line) {
-		value = swheaderline_get_value(line, (int*)NULL);
-		swi_com_assert_pointer((void*)value, __FILE__, __LINE__);
-		swi->swi_pkgM->dfiles_attributeM = strdup(value);
-	} else {
-		swi->swi_pkgM->dfiles_attributeM = strdup(SW_A_dfiles);
-	}
-	
-	swi_com_header_manifold_reset(swheader);
-	obj = swheader_get_object_by_tag(swheader, SW_A_distribution, "*" );
-	line = swheader_get_attribute(swheader, SW_A_pfiles);
-	if (line) {
-		value = swheaderline_get_value(line, (int*)NULL);
-		swi_com_assert_pointer((void*)value, __FILE__, __LINE__);
-		swi->swi_pkgM->pfiles_attributeM = strdup(value);
-	} else {
-		swi->swi_pkgM->pfiles_attributeM = strdup(SW_A_pfiles);
-	}
-	return 0;
-	*/
 }
 
 void 
@@ -265,7 +233,6 @@ swi_package_delete(SWI_PACKAGE * s)
 	}
 	free((void*)(cplob_release(s->exlistM)));	
 
-	/* if (s->prev_swpath_exM) swpath_delete_export(s->prev_swpath_exM); */
 	if (s->catalog_entryM != (char*)NULL) free(s->catalog_entryM);
 	if (s->target_pathM != (char*)NULL) free(s->target_pathM);
 	if (s->target_hostM != (char*)NULL) free(s->target_hostM);
@@ -342,7 +309,6 @@ SWI * swi_create(void)
 	swi->nullfdM = open("/dev/null", O_RDWR);
 	memset(swi->tarbufM, '\0', sizeof(swi->tarbufM));
 	swi->distdataM = NULL;
-	/* swi->sh_dash_sM = (char*)NULL; */
 	swi->opt_alt_catalog_rootM = 0;
 	swi->swicolM = swicol_create();
 	swi->exported_catalog_prefixM = NULL;
@@ -465,8 +431,10 @@ swi_expand_shared_file_control_sripts(SWI * swi, SWI_XFILE * xfile)
 				SWHEADER_PEEK_NEXT);
 		path_attr = swheader_get_attribute(swheader,
 			SW_A_path);
+		SWLIB_ASSERT(path_attr != NULL);
 		tag_attr = swheader_get_attribute(swheader,
 			SW_A_tag);
+		SWLIB_ASSERT(tag_attr != NULL);
 
 		/*
 		 * Now search the control scripts to see if this
@@ -563,7 +531,6 @@ swi_parse_file(
 
 	swheader = swheader_open((char *(*)(void *, int *, int))(NULL), NULL);
 	swheader_set_image_head(swheader, newbase);	
-	/* swheader_set_image_length(swheader, len); */	
 	uxfio_lseek(curfd, (off_t)0, SEEK_SET);
 
 	swi_com_assert_pointer((void*)(swi->swi_pkgM), __FILE__, __LINE__);
@@ -1253,7 +1220,6 @@ swi_do_decode(SWI * swi, SWLOG * swutil,
 	}	
 	ifd = xformat_get_ifd(xformat);	
 	swi->optaM = (void*)opta;
-	/* swi->swc_idM = SWC_U_I; */
 	swi->debug_eventsM = do_debug_events;
 	
 	/*
