@@ -122,7 +122,11 @@ typedef struct {			/* The global package structure	*/
 	int is_minimal_layoutM;		/* does have empty control dirs */
 	char * locationM;		/* location spec */
 	char * qualifierM;		/* qualifier spec */
-	char * installer_sigM;
+	char * installer_sigM;          /* gpg signature by swinstall */
+	char * installed_catalog_ownerM; /* owner of installed_software_catalog */
+	char * installed_catalog_groupM; /* group of installed_software_catalog */
+	mode_t installed_catalog_modeM;	 /* mode of installed_software_catalog */
+
 } SWI_PACKAGE;
 
 typedef struct {
