@@ -212,7 +212,7 @@ swi_com_do_preview(TARU * taru, struct new_cpio_header * file_hdr,
 	if (ftype >= 0) 
 		ls_list(ahsStaticGetTarFilename(file_hdr),
 			ahsStaticGetTarLinkname(file_hdr),
-			&sb, 
+			file_hdr, 
 			now, 
 			stdout,
 			uname, /* ahsStaticGetTarUsername(file_hdr), */
