@@ -77,9 +77,6 @@ taru_write_archive_member_data_(TARU * taru,
 
 		if (fout == NULL) {
 			E_DEBUG("");
-			/*
-			ret = swlib_digs_copy(out_file_des, input_fd, (intmax_t)(file_hdr0->c_filesize), digs, adjuct_ofd);
-			*/
 			ret = swlib_pump_amount8(out_file_des, input_fd, (intmax_t)(file_hdr0->c_filesize), adjuct_ofd, digs);
 			E_DEBUG2("ret=%s", swlib_imaxtostr(ret, NULL));
 
@@ -490,7 +487,7 @@ taru_write_archive_file_data(TARU * taru,
 
 int
 taru_write_archive_member_header(TARU * taru,
-				struct stat *file_stat,
+				struct stat * file_stat,
 				struct new_cpio_header * file_hdr0,
 				HLLIST * linkrecord,
 				DEFER * defer,
@@ -524,12 +521,7 @@ taru_write_archive_member_header(TARU * taru,
 	 * Set Info from the file_hdr0
 	 */
 	taru_filehdr2filehdr(file_hdr, file_hdr0);
-	if (file_stat) {
-		E_DEBUG("file_stat is true");
-		taru_statbuf2filehdr(file_hdr, file_stat, NULL,
-				ahsStaticGetTarFilename(file_hdr),
-				ahsStaticGetTarLinkname(file_hdr));
-	}
+	SWLIB_ASSERT(file_stat == NULL);
 
 	/*
 	 * If file_stat is not given, we assume we are not archiving a
@@ -1144,7 +1136,6 @@ taru_process_copy_out(TARU * taru, int input_fd, int out_file_des,
 			int ls_fd, int ls_verbose_level, intmax_t * nb, FILE_DIGS * digs)
 {
 	STROB * ls_tmp;
-	struct stat file_stat;
 	struct new_cpio_header * file_hdr0;
 	union tar_record tar_rec;
 	struct tar_header *tar_hdr = (struct tar_header *) &tar_rec;
@@ -1218,26 +1209,19 @@ taru_process_copy_out(TARU * taru, int input_fd, int out_file_des,
 					buf, (int*)NULL, 0, header_length);
 
 
-		if (taru_filehdr2statbuf(&file_stat, file_hdr0) < 0) {
-			fprintf(stderr, "%s",
-					ahsStaticGetTarFilename(file_hdr0));
-			ahsStaticDeleteFilehdr(file_hdr0);
-			return -8;
-		} else {
-			retx = tarui_write_archive_member_
-				(taru, &file_stat, file_hdr0,
-					hllist, defer, porinode,
-					out_file_des, 
-					input_fd, archive_format_out,
-					/*tarheaderflags*/ 0);
-			/* was in the write member_data function */
-			taru_tape_skip_padding(input_fd,
-						file_hdr0->c_filesize,
-							arf_ustar);
-			if (retx < 0)
-				return -9;
-			retvalx += retx;
-		}
+		retx = tarui_write_archive_member_
+			(taru, (struct stat*)NULL, file_hdr0,
+				hllist, defer, porinode,
+				out_file_des, 
+				input_fd, archive_format_out,
+				/*tarheaderflags*/ 0);
+		/* was in the write member_data function */
+		taru_tape_skip_padding(input_fd,
+					file_hdr0->c_filesize,
+						arf_ustar);
+		if (retx < 0)
+			return -9;
+		retvalx += retx;
 
 		if (ls_fd >= 0) {
 			taru_print_tar_ls_list(ls_tmp, file_hdr0, ls_verbose_level);
