@@ -609,12 +609,12 @@ taru_read_in_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 	if (header_buffer == NULL) {
 		tmpret = taru_tape_buffered_read(in_des, (void *)(&tar_rec), TARRECORDSIZE);
 		if (tmpret > 0 && tmpret != TARRECORDSIZE) {
-			fprintf(stderr, "otar.c: short read in read_in_tar_header2 return=%d\n", tmpret);
+			fprintf(stderr, "%s: otar.c: short read in read_in_tar_header2 return=%d\n", swlib_utilname_get(), tmpret);
 			return -1;
 		} else if (tmpret == 0) {
 			return 0;
 		} else if (tmpret < 0) {
-			fprintf(stderr, "otar.c: read error from read_in_tar_header2 return=%d\n", tmpret);
+			fprintf(stderr, "%s: otar.c: read error from read_in_tar_header2 return=%d\n", swlib_utilname_get(), tmpret);
 			return -1;
 		} else {
 			; /* Ok */
@@ -1213,6 +1213,8 @@ taru_write_out_tar_header2(TARU * taru, struct new_cpio_header *file_hdr,
 	}
 
 	if (tar_hdr->typeflag == CHRTYPE || tar_hdr->typeflag == BLKTYPE) {
+		/* fprintf(stderr, "JLJL major here %d\n", (int)(file_hdr->c_rdev_maj)); */
+		/* fprintf(stderr, "JLJL minor here %d\n", (int)(file_hdr->c_rdev_min)); */
 		MAJOR_TO_CHARS(file_hdr->c_rdev_maj, tar_hdr->devmajor, termch);
 		MINOR_TO_CHARS(file_hdr->c_rdev_min, tar_hdr->devminor, termch);
 	} else {
@@ -1341,7 +1343,7 @@ taru_datoul (char * s, unsigned long *n)
           val = 10 * val + *s++ - '0';
   }
   if (oldval && ((val / oldval) < 10)) {
-	fprintf(stderr, "taru_datoul : conversion overflow\n");
+	fprintf(stderr, "%s, taru_datoul : conversion overflow\n", swlib_utilname_get());
 	return 2;
   }
   while (*s == ' ') ++s;
