@@ -196,10 +196,6 @@ taru_init_header(struct new_cpio_header * file_hdr)
        	file_hdr->c_cu = TARU_C_BY_USYS;
        	file_hdr->c_cg = TARU_C_BY_GSYS;
        	file_hdr->c_is_tar_lnktype = -1;
-       	file_hdr->c_name = NULL;
-       	file_hdr->c_tar_linkname = NULL;
-       	file_hdr->c_username = NULL;
-       	file_hdr->c_groupname = NULL;
 	ahsStaticSetTarGroupname(file_hdr, "");
 	ahsStaticSetTarUsername(file_hdr, "");
 	ahsStaticSetTarLinkname(file_hdr, "");
@@ -212,7 +208,11 @@ struct new_cpio_header *
 taru_make_header(void)
 {
 	struct new_cpio_header *hnew;
-	hnew=malloc(sizeof(struct new_cpio_header));
+	hnew = malloc(sizeof(struct new_cpio_header));
+       	hnew->c_name = NULL;
+       	hnew->c_tar_linkname = NULL;
+       	hnew->c_username = NULL;
+       	hnew->c_groupname = NULL;
 	taru_init_header(hnew);
 	return hnew;
 }
@@ -254,6 +254,10 @@ void
 taru_free_header(struct new_cpio_header *h)
 {
 	taru_free_header_digs(h);
+	ahsStaticSetTarGroupname(h, NULL); /* these have effect of calling */
+	ahsStaticSetTarUsername(h, NULL);  /* strob_close() */
+	ahsStaticSetTarLinkname(h, NULL);
+	ahsStaticSetTarFilename(h, NULL);
 	swbis_free(h);
 }
 
@@ -422,3 +426,24 @@ taru_set_tar_header_policy(TARU * taru, char * user_format, int * p_arf_format)
 	}
 	return 0;
 }
+
+int
+taru_check_devno_for_tar(struct new_cpio_header * file_hdr)
+{
+	if (file_hdr->c_rdev_maj > 2097151)  /* & 07777777 != file_hdr->c_rdev_maj) */
+		return 1;
+	if (file_hdr->c_rdev_min > 2097151)  /* & 07777777 != file_hdr->c_rdev_min) */
+		return 2;
+	return 0;
+}
+
+int
+taru_check_devno_for_system(struct new_cpio_header * file_hdr)
+{
+	int d = makedev(file_hdr->c_rdev_maj, file_hdr->c_rdev_min);
+	if ((int)(file_hdr->c_rdev_maj) != (int)minor(d))
+		return 1;
+	if ((int)(file_hdr->c_rdev_min) != (int)minor(d))
+		return 2;
+	return 0;
+}
