@@ -406,5 +406,7 @@ int taru_set_tar_header_policy(TARU * taru, char * user_format, int * p_arf_form
 FILE_DIGS * taru_digs_create(void);
 void taru_digs_init(FILE_DIGS *, int, int);
 void taru_digs_print(FILE_DIGS * digs, STROB * );
+int taru_check_devno_for_system(struct new_cpio_header * file_hdr);
+int taru_check_devno_for_tar(struct new_cpio_header * file_hdr);
 
 #endif
