@@ -122,7 +122,7 @@ internal_set_format (XFORMAT * xux, int * instance_format, int format)
 static 
 int
 common_setup_write_header(XFORMAT * xux, struct new_cpio_header **p_hdr1, 
-			struct stat **p_lt1, struct new_cpio_header *hdr0, 
+			struct new_cpio_header *hdr0, 
 				struct stat *t_stat, char * t_name, 
 						char * t_source)
 {
@@ -132,7 +132,6 @@ common_setup_write_header(XFORMAT * xux, struct new_cpio_header **p_hdr1,
                 // only lstat the source if name is null.
 	        */ 
 		*strob_str(xux->linkname2M) = '\0';
-
 		*p_hdr1=(struct new_cpio_header*)(xformat_vfile_hdr(xux));
 		if (!t_name ) {
                     	char * p1_name = ahsStaticGetTarFilename(*p_hdr1);
@@ -150,13 +149,11 @@ common_setup_write_header(XFORMAT * xux, struct new_cpio_header **p_hdr1,
 			* //
 			*/
 			XFORMAT_E_DEBUG("[0 0 0]");
-			*p_lt1 = NULL;
 		} else if (t_name == NULL  && t_stat == NULL && t_source) {
 			/*
 			* Use the vfile header for stats.
 			* but get the size from the source.
 			*/
-			*p_lt1 = NULL;
 			XFORMAT_E_DEBUG("[0 0 1]");
 			XFORMAT_E_DEBUG2("[0 0 1] %s", t_source);
 			if (lstat (t_source, &(xux->lt2M)) != 0 ) {
@@ -208,7 +205,6 @@ common_setup_write_header(XFORMAT * xux, struct new_cpio_header **p_hdr1,
 			#endif
 			ahsStaticSetTarFilename(hdr0, strob_str(xux->name2M));
 			ahsStaticSetTarLinkname(hdr0, strob_str(xux->linkname2M));
-			*p_lt1 = &(xux->lt2M);
 			*p_hdr1 = hdr0;
 		 } else if ( (t_stat && t_name && t_source == NULL) ||
 					(t_stat && t_name && t_source) ) {
@@ -224,7 +220,6 @@ common_setup_write_header(XFORMAT * xux, struct new_cpio_header **p_hdr1,
 			XFORMAT_E_DEBUG("[1 1 0] || [1 1 1]");
 			XFORMAT_E_DEBUG3("[1 1 0] || [1 1 1] %s %s", t_name , t_source);
 			taru_statbuf2filehdr(hdr0, t_stat, t_source, strob_str(xux->name2M) , strob_str(xux->linkname2M));
-			*p_lt1 = NULL;
 			*p_hdr1 = hdr0;
 			#ifdef TARUNEEDDEBUG
 			XFORMAT_E_DEBUG2("[1 1 0]||[1 1 1]  %s", taru_header_dump_string_s(hdr0, "[1 1 0]||[1 1 1] hdr0 "));
@@ -247,7 +242,6 @@ common_setup_write_header(XFORMAT * xux, struct new_cpio_header **p_hdr1,
 				taru_statbuf2filehdr(hdr0, &(xux->lt2M),
 					t_source, strob_str(xux->name2M),
 						strob_str(xux->linkname2M));
-				*p_lt1 = NULL;
 				*p_hdr1 = hdr0;
 		 	}
 			#ifdef TARUNEEDDEBUG
@@ -835,17 +829,15 @@ int
 xformat_write_header_wn(XFORMAT * xux, char * name)
 {
 	struct new_cpio_header *hdr1;
-	struct stat *lt1;
         struct  new_cpio_header * hdr0;
 	int ret;
 	
 	XFORMAT_E_DEBUG("");
         hdr0 = ahsStaticCreateFilehdr();
-	ret = common_setup_write_header(xux, &hdr1, &lt1, hdr0,
-				(struct stat*)(NULL), name, (char*)NULL);
+	ret = common_setup_write_header(xux, &hdr1, hdr0, (struct stat*)(NULL), name, (char*)NULL);
 	if (ret == 0) {
 		ret = taru_write_archive_member_header(xux->taruM, 
-						lt1, hdr1, 
+						NULL, hdr1, 
 						xux->link_recordM,
 						xux->deferM, 
 						xux->use_false_inodesM,
@@ -873,7 +865,6 @@ xformat_write_file_by_fd (XFORMAT * xux,
 {
         struct  new_cpio_header * hdr0 = ahsStaticCreateFilehdr();
 	struct new_cpio_header *hdr1;
-	struct stat *lt1;
 	intmax_t ret;
 	intmax_t ret1;
 	XFORMAT_E_DEBUG("");
@@ -889,9 +880,9 @@ xformat_write_file_by_fd (XFORMAT * xux,
 		ahsStaticDeleteFilehdr(hdr0);
 		return ret;
 	}
-	if((ret=common_setup_write_header(xux, &hdr1, &lt1, 
+	if((ret=common_setup_write_header(xux, &hdr1,
 				hdr0, t, name, (char*)NULL)) == 0) {
-		if ((ret=taru_write_archive_member_header(xux->taruM, lt1, 
+		if ((ret=taru_write_archive_member_header(xux->taruM, NULL, 
 					hdr1, 
 					xux->link_recordM, 
 					xux->deferM, 
@@ -975,11 +966,9 @@ xformat_write_file(XFORMAT * xux, struct stat *t, char * name, char * source)
         intmax_t ret=0, ret1, fd=-1; 
         struct new_cpio_header * hdr0 = ahsStaticCreateFilehdr();
 	struct new_cpio_header *hdr1;
-	struct stat *lt1;
 		
 	XFORMAT_E_DEBUG("");
-	ret = common_setup_write_header(xux, &hdr1, &lt1, hdr0, t,  
-							name, source);
+	ret = common_setup_write_header(xux, &hdr1, hdr0, t, name, source);
     	/*
 	* hdr1 is now the object vfile header.
 	*/
@@ -1011,17 +1000,7 @@ xformat_write_file(XFORMAT * xux, struct stat *t, char * name, char * source)
 	        }
 	}
 
-	if (lt1) {
-		/*
-		 * This happens for control directories that are not in
-		 * the filesystem
-		 */
-		XFORMAT_E_DEBUG2("lt1 is not NULL [%s]\n", source);
-	} else {
-		XFORMAT_E_DEBUG2("lt1 is NULL [%s]\n", source);
-	}
-
-	ret=taru_write_archive_member_header(xux->taruM, lt1, 
+	ret=taru_write_archive_member_header(xux->taruM, NULL, 
 					hdr1, 
 					xux->link_recordM, 
 					xux->deferM, 
