@@ -4,7 +4,7 @@
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -14,11 +14,12 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifndef xformat_20001001_jhl_h
 #define xformat_20001001_jhl_h
 
+#include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -48,7 +49,7 @@ typedef struct {
 	enum archive_format output_format_codeM;
 
 	int eoaM;
-	int bytes_writtenM;
+	uintmax_t bytes_writtenM;
 	int make_false_inodesM;
 	SWVARFS * swvarfsM;
 	AHS * ahsM;
@@ -113,7 +114,7 @@ typedef struct {
 
 	void xformat_set_gid(XFORMAT * xux, gid_t gid ); 
   
-	void xformat_set_filesize(XFORMAT * xux, int filesize ); 
+	void xformat_set_filesize(XFORMAT * xux, intmax_t filesize ); 
 
 	void xformat_set_nlink(XFORMAT * xux, int  nlink);
 	
@@ -163,21 +164,21 @@ typedef struct {
 	
 	int xformat_clear_pass_buffer(XFORMAT * xux); 
 	
-	int xformat_write_file_data(XFORMAT * xux, int source_fd);
+	intmax_t xformat_write_file_data(XFORMAT * xux, int source_fd);
 	
-	int xformat_read_file_data(XFORMAT * xux, int dst_fd);
+	intmax_t xformat_read_file_data(XFORMAT * xux, int dst_fd);
 
 	int xformat_write_header(XFORMAT * xux);
 
 	int xformat_write_header_wn(XFORMAT * xux, char * name);
 	
-	int xformat_write_by_name(XFORMAT * xux, char * name, struct stat *st);
+	intmax_t xformat_write_by_name(XFORMAT * xux, char * name, struct stat *st);
 
-	int xformat_write_by_fd(XFORMAT * xux, int srcfd, struct new_cpio_header * file_hdr);
+	intmax_t xformat_write_by_fd(XFORMAT * xux, int srcfd, struct new_cpio_header * file_hdr);
 	
-	int xformat_write_file_by_fd(XFORMAT * xux, struct stat *t, char * name, int(*)(int), int source_fd);
+	intmax_t xformat_write_file_by_fd(XFORMAT * xux, struct stat *t, char * name, int(*)(int), int source_fd);
 	
-	int xformat_write_file(XFORMAT * xux, struct stat *t, char * name, char * source);
+	intmax_t xformat_write_file(XFORMAT * xux, struct stat *t, char * name, char * source);
 
 	int xformat_write_trailer(XFORMAT * xux);
 	
@@ -211,16 +212,19 @@ typedef struct {
 
 	int xformat_read (XFORMAT * xux, void * buf, size_t count); 
 
-	int xformat_copy_pass_thru(XFORMAT * xux); 
+	intmax_t xformat_copy_pass_thru(XFORMAT * xux); 
 
-	int xformat_copy_pass_by_dst(XFORMAT * xux, int dst_fd);
+	intmax_t xformat_copy_pass_by_dst(XFORMAT * xux, int dst_fd);
 
-	int xformat_copy_pass(XFORMAT * xux, int dst_fd, int src_fd);
-	int xformat_copy_pass_md5(XFORMAT * xux, int dst_fd, int src_fd, char * md5buf);
+	intmax_t xformat_copy_pass_digs(XFORMAT * xux, int dst_fd, int src_fd, FILE_DIGS * digs);
 	
-	int xformat_copy_pass_file_data(XFORMAT * xux, int dst_fd, int src_fd);
+	intmax_t xformat_copy_pass(XFORMAT * xux, int dst_fd, int src_fd);
 
-	int xformat_copy_pass2 (XFORMAT * xux, int dst_fd, int src_fd, int adjunct_ofd);
+	intmax_t xformat_copy_pass_md5(XFORMAT * xux, int dst_fd, int src_fd, char * md5buf);
+	
+	intmax_t xformat_copy_pass_file_data(XFORMAT * xux, int dst_fd, int src_fd);
+
+	intmax_t xformat_copy_pass2 (XFORMAT * xux, int dst_fd, int src_fd, int adjunct_ofd);
 
 	char xformat_get_tar_typeflag (XFORMAT * xux);
 	
@@ -236,7 +240,7 @@ typedef struct {
 
 	char* xformat_get_tar_groupname (XFORMAT * xux);
 
-	size_t xformat_get_filesize (XFORMAT * xux);
+	intmax_t xformat_get_filesize (XFORMAT * xux);
 
 	time_t xformat_get_mtime (XFORMAT * xux);
 	
