@@ -402,6 +402,7 @@ uinfile_i_open(char *filename, int oflag, mode_t mode, UINFORMAT ** uinformat,
 	char Zmagic[] = UINFILE_MAGIC_Z;
 	char rpmmagic[] = UINFILE_MAGIC_rpm;
 	char bz2magic[] = UINFILE_MAGIC_bz2;
+	char lzmamagic[] = UINFILE_MAGIC_lzma;
 	char debmagic[] = UINFILE_MAGIC_deb;
 	char slackmagic[] = UINFILE_MAGIC_slack;
 	char *zcat_command = (char *) (NULL);
@@ -707,10 +708,23 @@ LABEL_REREAD:
 							/* bz2 compression */
 			UINFILE_E_DEBUG("type: COMPRESSED_BZ2");
 			(*uinformat)->ztypeM = UINFILE_COMPRESSED_BZ2;
+		} else if (!memcmp(xbuffer, (void *) lzmamagic, 3)) {
+							/* LZMA compression */
+			UINFILE_E_DEBUG("type: COMPRESSED_LZMA");
+			(*uinformat)->ztypeM = UINFILE_COMPRESSED_LZMA;
 		} else if (!memcmp(xbuffer, (void *) Zmagic, 2)) {
 							/* Unix compress */
 			UINFILE_E_DEBUG("type: COMPRESSED_Z");
 			(*uinformat)->ztypeM = UINFILE_COMPRESSED_Z;
+		} else if (
+			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_armor,  strlen(UINFILE_MAGIC_gpg_armor)) == 0 ||
+			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_sym,  strlen(UINFILE_MAGIC_gpg_sym)) == 0 ||
+			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_enc1,  strlen(UINFILE_MAGIC_gpg_enc1)) == 0 ||
+			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_enc2,  strlen(UINFILE_MAGIC_gpg_enc2)) == 0 ||
+			0
+		) {
+			UINFILE_E_DEBUG("type: GPG Encrypted");
+			(*uinformat)->ztypeM = UINFILE_COMPRESSED_GPG;
 		} else if ( donative == 0 &&
 			dounrpminstall == 0 &&
 			memcmp(xbuffer, (void *)debmagic, strlen(UINFILE_MAGIC_deb)) == 0
@@ -1102,10 +1116,23 @@ LABEL_REREAD:
 							/* bz2 compression */
 			UINFILE_E_DEBUG("");
 			(*uinformat)->ztypeM = UINFILE_COMPRESSED_BZ2;
+		} else if (!memcmp(xbuffer, (void *) lzmamagic, 3)) {
+							/* LZMA compression */
+			UINFILE_E_DEBUG("");
+			(*uinformat)->ztypeM = UINFILE_COMPRESSED_LZMA;
 		} else if (!memcmp(xbuffer, (void *) Zmagic, 2)) {
 							/* Unix compress */
 			UINFILE_E_DEBUG("");
 			(*uinformat)->ztypeM = UINFILE_COMPRESSED_Z;
+		} else if (
+			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_armor,  strlen(UINFILE_MAGIC_gpg_armor)) == 0 ||
+			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_sym,  strlen(UINFILE_MAGIC_gpg_sym)) == 0 ||
+			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_enc1,  strlen(UINFILE_MAGIC_gpg_enc1)) == 0 ||
+			memcmp(xbuffer, (void *) UINFILE_MAGIC_gpg_enc2,  strlen(UINFILE_MAGIC_gpg_enc2)) == 0 ||
+			0
+		) {
+			UINFILE_E_DEBUG("type: GPG Encrypted");
+			(*uinformat)->ztypeM = UINFILE_COMPRESSED_GPG;
 		} else {
 			UINFILE_E_DEBUG("");
 			ret =  uinfile_handle_return(*uinformat,
@@ -1180,6 +1207,20 @@ LABEL_REREAD:
 		unzip[0] = shcmd_open();
 		shcmd_add_arg(unzip[0], "bzip2");
 		shcmd_add_arg(unzip[0], "-d");
+	} else if ((*uinformat)->ztypeM == UINFILE_COMPRESSED_LZMA) {
+		UINFILE_E_DEBUG("in lzma code");
+		unzip[0] = shcmd_open();
+		shcmd_add_arg(unzip[0], "lzma");
+		shcmd_add_arg(unzip[0], "-d");
+	} else if ((*uinformat)->ztypeM == UINFILE_COMPRESSED_GPG) {
+		UINFILE_E_DEBUG("in gpg code");
+		unzip[0] = shcmd_open();
+		shcmd_add_arg(unzip[0], "gpg");
+		shcmd_add_arg(unzip[0], "--decrypt");
+		shcmd_add_arg(unzip[0], "--use-agent");
+		shcmd_add_arg(unzip[0], "--no-verbose");
+		shcmd_add_arg(unzip[0], "-o");
+		shcmd_add_arg(unzip[0], "-");
 	} else if ((*uinformat)->ztypeM == UINFILE_COMPRESSED_CPIO) {
 		UINFILE_E_DEBUG("in unrpm code");
 		unzip[0] = shcmd_open();
