@@ -35,16 +35,18 @@
 #define UINFILE_AR_SIZE_OFFSET  48
 */
 
-#define UINFILE_COMPRESSED_NOT 		0
-#define UINFILE_COMPRESSED_Z 		1
-#define UINFILE_COMPRESSED_GZ 		2
-#define UINFILE_COMPRESSED_BZ 		3
+#define UINFILE_COMPRESSED_NA 		-1   /* not applicable */
+#define UINFILE_COMPRESSED_NOT 		0    /* Not compressed */
+#define UINFILE_COMPRESSED_Z 		1    /* Old Unix Z */
+#define UINFILE_COMPRESSED_GZ 		2    /* gzip */
+#define UINFILE_COMPRESSED_BZ 		3    /* actually bz2 */
 #define UINFILE_COMPRESSED_BZ2 		4
 #define UINFILE_COMPRESSED_RPM		5    /* RPM is modeled as a compression type */
 #define UINFILE_COMPRESSED_CPIO		6    /* CPIO format is modeled as a compression type */
 					     /* for purposes of transparent conversion to tar format */
 #define UINFILE_COMPRESSED_DEB		7    /* DEB format is modeled as a compression type */
-#define UINFILE_COMPRESSED_NA 		-1   /* not applicable */
+#define UINFILE_COMPRESSED_LZMA		8    /* LZMA compressed */
+#define UINFILE_COMPRESSED_GPG		9    /* GPG encrypted */
 
 #define UINFILE_IEEE_MAX_LEADING_DIR 	3  /* Maximum no of dirs before .../catalog/INDEX file */
 
@@ -55,11 +57,16 @@
 #define UINFILE_MAGIC_Z 	"\x1f\x9d\x90\x00"
 #define UINFILE_MAGIC_rpm 	"\xed\xab\xee\xdb"
 #define UINFILE_MAGIC_bz2 	"\x42\x5a\x68"
+#define UINFILE_MAGIC_lzma 	"\x5d\x00\x00\x80"
 #define UINFILE_MAGIC_ar 	"!<arch>\n"
 #define UINFILE_MAGIC_deb 	UINFILE_MAGIC_ar "debian-binary"
 #define UINFILE_MAGIC_binary_tarball	"./"
 #define UINFILE_MAGIC_slack	"install"
 #define UINFILE_MAGIC_slack_desc	UINFILE_MAGIC_slack "slack-desc"
+#define UINFILE_MAGIC_gpg_armor "-----BEGIN PGP"
+#define UINFILE_MAGIC_gpg_sym	"\x8c\x0d"
+#define UINFILE_MAGIC_gpg_enc1	"\x85\x01"
+#define UINFILE_MAGIC_gpg_enc2	"\x85\x02"
 
 #define UINFILE_SWBIS_PATH0	"catalog/swbis-0.2/"
 #define UINFILE_SW_MAGIC	"catalog/INDEX"
