@@ -205,12 +205,31 @@ extern const struct headerSprintfExtension rpmHeaderFormats[];
 
 #define	RPMSENSE_ANY		0
 #define	RPMSENSE_SERIAL		(1 << 0) /* eliminated, backward compatibilty */
+
+#ifndef RPMSENSE_LESS
 #define	RPMSENSE_LESS		(1 << 1)
+#endif
+
+#ifndef RPMSENSE_GREATER
 #define	RPMSENSE_GREATER	(1 << 2)
+#endif
+
+#ifndef RPMSENSE_EQUAL
 #define	RPMSENSE_EQUAL		(1 << 3)
+#endif
+
+#ifndef RPMSENSE_PROVIDES
 #define	RPMSENSE_PROVIDES	(1 << 4) /* only used internally by builds */
+#endif
+
+#ifndef RPMSENSE_CONFLICTS
 #define	RPMSENSE_CONFLICTS	(1 << 5) /* only used internally by builds */
+#endif
+
+#ifndef RPMSENSE_PREREQ
 #define	RPMSENSE_PREREQ		(1 << 6)
+#endif
+
 #define	RPMSENSE_OBSOLETES	(1 << 7) /* only used internally by builds */
 #define	RPMSENSE_SENSEMASK	15	 /* Mask to get senses, ie serial, */
                                          /* less, greater, equal.          */
@@ -721,7 +740,7 @@ int showMatches(QVA_t *qva, rpmdb db, dbiIndexSet matches, QVF_t showPackage);
 #define QUERY_FOR_CONFIG	(1 << 4)
 #define QUERY_FOR_DUMPFILES     (1 << 8)
 
-/*@observer@*/ const char *const tagName(int tag);
+/*@observer@*/ const char * const tagName(int tag);
 extern int specedit;
 /*
 extern struct poptOption rpmQueryPoptTable[];
