@@ -1,3 +1,4 @@
+#include "swuser_config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -9,8 +10,12 @@
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/fcntl.h>
+#include "swmain.h"
+#include "swfork.h"
 #include "uxfio.h"
 
+
+
 void get_string (char *str);
 int get_integer (int j);
 
