@@ -246,7 +246,7 @@ main(int argc, char **argv)
 			break;
 		case '3':	
 			switer->set_stack_index(1);
-  			swspsf->write(STDOUT_FILENO);
+  			swspsf->iwrite(STDOUT_FILENO);
 			switer->show_debug(stdout);
 			break;
 
@@ -355,7 +355,7 @@ main(int argc, char **argv)
 			if (!sws){
 				fprintf(stderr, "inode %d not found.\n", n);	
 			} else {
-				sws->write(STDOUT_FILENO);
+				sws->iwrite(STDOUT_FILENO);
 				flush(cout);
 				swheader_set_current_offset_p_value(swheader, sws->get_swdefinition()->get_ino());
 			}
@@ -561,7 +561,7 @@ main(int argc, char **argv)
 				fprintf(stderr, "offset %d  not found.\n", obj - swheader_get_image_head(swheader));	
 				break;
 			}
-			sws->write(STDOUT_FILENO);
+			sws->iwrite(STDOUT_FILENO);
 			flush(cout);
 			break;	
 		
