@@ -14,7 +14,7 @@
 #include "swindex.h"
 #include "uxformat.h"
 
-#include "swparser_global.h"
+#include "swmain.h"
 
 int main (int argc, char ** argv) {
 	int format_code = arf_ustar;
