@@ -24,7 +24,7 @@ echo
 GNUPGHOME="$gpg_homedir"
 export GNUPGHOME
 
-swign -u "$AUTHOR" @- | swverify --checksig
+swign -s . -u "$AUTHOR" @- | swverify --checksig
 
 ret=$?
 rm -fr /var/tmp/swbis-test-user$$
